package at.jku.koppensteiner.androgios;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.service.PollingService;
import at.jku.koppensteiner.androgios.util.DateHelper;
import at.jku.koppensteiner.androgios.util.MenuHelper;

public abstract class AbstractModelActivity extends Activity{

	protected class ModelUpdateReceiver extends BroadcastReceiver{

		@Override
		public void onReceive(Context context, Intent intent) {
			update();
		}
		
	}
	
	public static final String ACTION_MODEL_UPDATE = "at.jku.koppensteiner.androgios.intent.action.MODEL_UPDATE";
	protected ModelUpdateReceiver modelUpdateReceiver;
	NagiosInstance instance;
	
	@Override
	protected void onResume() {
		super.onResume();
	}
	
	@Override
	protected void onPause() {
		super.onPause();
	}
	
	@Override
	protected void onDestroy(){
		super.onDestroy();
		getApplicationContext().unregisterReceiver(modelUpdateReceiver);
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		
		final IntentFilter intentFilter = new IntentFilter(ACTION_MODEL_UPDATE);
		modelUpdateReceiver = new ModelUpdateReceiver();
		getApplicationContext().registerReceiver(modelUpdateReceiver, intentFilter);
		
		instance = MasterController.getInstance().getActiveNagiosInstance();
		
	}
	
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
    	return MenuHelper.addDefaultMenu(menu);
    }
    
    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {
    	return MenuHelper.updateServiceMenuItem(menu);
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
    	if(item.getItemId()==MenuHelper.REFRESH_ID){
    		poll();
    	}else if(item.getItemId()== MenuHelper.SERVICE_ID && !PollingService.running){
    		MasterController.getInstance().enableService();
    	}else if(item.getItemId()== MenuHelper.SERVICE_ID && PollingService.running){
    		MasterController.getInstance().disableService();
    	}else if(item.getItemId()== MenuHelper.CONFIGURE_ID){
    		Intent intent = new Intent();
			intent.setClass(MasterController.getInstance().getAppCtx(), ConfigActivity.class);
    		startActivity(intent);
    	}//*/
    	return super.onOptionsItemSelected(item);
    }
	
    
	protected void update(){
		if(!instance.model.updateSuccessful){
			TextView txtHeader = ((TextView)findViewById(R.id.textViewModelUpdate));
			
			if(instance.model.errorCause == MonitoringModel.ERRORCAUSE_SSL){
    			txtHeader.setText(R.string.updatefailedSSL);
    		}else{
    			txtHeader.setText(R.string.updatefailed);
    		}
			
			return;
		}
		
		((TextView)findViewById(R.id.textViewModelUpdate)).setText(getString(R.string.lastUpdateHeader)+" "+DateHelper.simpleDate(instance.model.lastUpdate));
		
	}
	
	protected void poll(){
		((TextView)findViewById(R.id.textViewModelUpdate)).setText(R.string.polling);
	}
}
