package at.jku.koppensteiner.androgios;

import android.app.Activity;
import android.app.NotificationManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.TacticalOverview;
import at.jku.koppensteiner.androgios.service.PollingService;
import at.jku.koppensteiner.androgios.util.DateHelper;
import at.jku.koppensteiner.androgios.util.MenuHelper;


public class AndrogiosActivity extends Activity {
	
	
	
	public class TACAdapter extends BaseAdapter{
		
		TacticalOverview tac;
		
		public TACAdapter(TacticalOverview tac){
			this.tac = tac;
		}

		@Override
		public int getCount() {
			if(tac.updateSuccessful){
				return 4;
			}
			return 0;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			TextView txtHeader = new TextView(AndrogiosActivity.this);
			TextView txtData = new TextView(AndrogiosActivity.this);
			txtHeader.setTextColor(Color.BLACK);
			txtData.setTextColor(Color.BLACK);
			LinearLayout ll = new LinearLayout(AndrogiosActivity.this);
			ll.setBackgroundColor(Color.GREEN);
			StringBuilder sb = new StringBuilder();
			
			ll.setOrientation(LinearLayout.VERTICAL);
			txtData.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			
			switch(position){

			case 0:
				txtHeader.setText(R.string.healthHeader);
				sb.append(getString(R.string.hostsHeader));
				sb.append(" ");
				sb.append(tac.hostHealth);
				sb.append("\n");
				sb.append(getString(R.string.servicesHeader));
				sb.append(" ");
				sb.append(tac.serviceHealth);
				txtData.setText(sb.toString());

				if(tac.hasImportantProblem()){
					ll.setBackgroundColor(Color.RED);
				}else if(tac.hasUnimportantProblem()){
					ll.setBackgroundColor(Color.YELLOW);
				}
				
				ll.addView(txtHeader);
				ll.addView(txtData);
				
				return ll;
			case 1:
				txtHeader.setText(R.string.outagesHeader);
				txtData.setText(tac.outagesSummary.outages);
				
				if(tac.hasImportantOutageProblem){
					ll.setBackgroundColor(Color.RED);
				}else if(tac.hasUnimportantOutageProblem){
					ll.setBackgroundColor(Color.YELLOW);
				}
				
				ll.addView(txtHeader);
				ll.addView(txtData);
				
				return ll;
			case 2:
				txtHeader.setText(R.string.hostsHeader);
				sb.append(tac.hostStatusSummary.hostsDown);
				sb.append("\n");
				sb.append(tac.hostStatusSummary.hostsUnreachable);
				sb.append("\n");
				sb.append(tac.hostStatusSummary.hostsUp);
				sb.append("\n");
				sb.append(tac.hostStatusSummary.hostsPending);
				txtData.setText(sb.toString());
				
				if(tac.hasImportantHostProblem){
					ll.setBackgroundColor(Color.RED);
				}else if(tac.hasUnimportantHostProblem){
					ll.setBackgroundColor(Color.YELLOW);
				}
				
				ll.addView(txtHeader);
				ll.addView(txtData);
				
				return ll;
			case 3:
				txtHeader.setText(R.string.servicesHeader);
				sb.append(tac.serviceStatusSummary.servicesCritical);
				sb.append("\n");
				sb.append(tac.serviceStatusSummary.servicesWarning);
				sb.append("\n");
				sb.append(tac.serviceStatusSummary.servicesUnknown);
				sb.append("\n");
				sb.append(tac.serviceStatusSummary.servicesOk);
				sb.append("\n");
				sb.append(tac.serviceStatusSummary.servicesPending);
				txtData.setText(sb.toString());
				
				
				if(tac.hasImportantServiceProblem){
					ll.setBackgroundColor(Color.RED);
				}else if(tac.hasUnimportantServiceProblem){
					ll.setBackgroundColor(Color.YELLOW);
				}
				
				ll.addView(txtHeader);
				ll.addView(txtData);
				
				return ll;
				
				
			}
			
			return new TextView(AndrogiosActivity.this);
		}

	}
	
	
	private class TacUpdateReceiver extends BroadcastReceiver{

		@Override
		public void onReceive(Context context, Intent intent) {
			update();
		}
		
	}
	
	
	public static final String ACTION_TAC_UPDATE = "at.jku.koppensteiner.androgios.intent.action.TAC_UPDATE";
	private TacUpdateReceiver tacUpdateReceiver;
	
	@Override
	protected void onResume() {
		
		super.onResume(); 
	}
	
	@Override
	protected void onPause() {
		
		super.onPause();
	}
	
	@Override
	protected void onDestroy(){
		super.onDestroy();
		getApplicationContext().unregisterReceiver(tacUpdateReceiver);
	}
	
	
	private NagiosInstance instance;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        MasterController mc = MasterController.getInstance();
        
        //register the application context
        mc.setAppCtx(getApplicationContext());
        
        final IntentFilter intentFilter = new IntentFilter(ACTION_TAC_UPDATE);
		tacUpdateReceiver = new TacUpdateReceiver();
		getApplicationContext().registerReceiver(tacUpdateReceiver, intentFilter);
        
        instance = mc.getActiveNagiosInstance();
        
		if(!instance.tacticalOverview.updateSuccessful){
			poll();
		}else{
			update();
		}
        
        
        
        addButtonListeners();
        
        //delete notification if shown
        final NotificationManager nm = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);
        nm.cancel(PollingService.NOTIFY_ID);
        
    }
    
    private void update(){
    	
    	if(!instance.tacticalOverview.updateSuccessful){
    		TextView txtHeader = (TextView)findViewById(R.id.textViewTACUpdate);
    		
    		if(instance.tacticalOverview.errorCause == TacticalOverview.ERRORCAUSE_SSL){
    			txtHeader.setText(R.string.updatefailedSSL);
    		}else{
    			txtHeader.setText(R.string.updatefailed);
    		}
    		
    		return;
    	}
    	
    	((TextView)findViewById(R.id.textViewTACUpdate)).setText(getString(R.string.lastUpdateHeader)+" "+DateHelper.simpleDate(instance.tacticalOverview.lastUpdate));
    	ListView list = (ListView) findViewById(R.id.listViewTAC);
		list.setAdapter(new TACAdapter(MasterController.getInstance().getActiveNagiosInstance().tacticalOverview));
	
		addListEntyListeners();
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
    	return MenuHelper.addDefaultMenu(menu);
    }
    
    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {
    	return MenuHelper.updateServiceMenuItem(menu);
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
    	if(item.getItemId()==MenuHelper.REFRESH_ID){
    		poll();
    	}else if(item.getItemId()== MenuHelper.SERVICE_ID && !PollingService.running){
    		MasterController.getInstance().enableService();
    	}else if(item.getItemId()== MenuHelper.SERVICE_ID && PollingService.running){
    		MasterController.getInstance().disableService();
    	}else if(item.getItemId()== MenuHelper.CONFIGURE_ID){
    		Intent intent = new Intent();
			intent.setClass(MasterController.getInstance().getAppCtx(), ConfigActivity.class);
    		startActivity(intent);
    	}//*/
    	return super.onOptionsItemSelected(item);
    }
    
    
    
    private void addListEntyListeners(){
    	ListView list = (ListView) findViewById(R.id.listViewTAC);
		list.setOnItemClickListener(new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				Intent intent = new Intent();
				switch(pos){
				
				case 1:
					intent.setClass(MasterController.getInstance().getAppCtx(), OutagesActivity.class);
					break;
				case 2:
					if(instance.tacticalOverview.hasImportantHostProblem || 
							instance.tacticalOverview.hasUnimportantHostProblem){
						intent.setClass(MasterController.getInstance().getAppCtx(), HostProblemsActivity.class);
					}else{
						intent.setClass(MasterController.getInstance().getAppCtx(), HostListActivity.class);
					}
					
					break;
				case 3:
					if(instance.tacticalOverview.hasImportantServiceProblem || 
							instance.tacticalOverview.hasUnimportantServiceProblem){
						intent.setClass(MasterController.getInstance().getAppCtx(), ServiceProblemsActivity.class);
					}else{
						intent.setClass(MasterController.getInstance().getAppCtx(), ServiceListActivity.class);
					}
					break;
				default:
					return;
					
				}
				startActivity(intent);
			}
		});
    }
    
    private void addButtonListeners(){
    	//navigation
    	OnClickListener naviListener = new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				Intent intent = new Intent();
				intent.setClass(MasterController.getInstance().getAppCtx(), NavigationActivity.class);
				startActivity(intent);
				
			}
		};
		
		((Button)findViewById(R.id.btnNavi)).setOnClickListener(naviListener);
		
		//refresh
		OnClickListener refreshListener = new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				poll();
				
			}
		};
		
		((Button)findViewById(R.id.btnRefresh)).setOnClickListener(refreshListener);
		
		//next one here...
		
    }
    
    private void poll(){
    	((TextView)findViewById(R.id.textViewTACUpdate)).setText(R.string.polling);
		instance.pollTacticalOverview();
    }
    
}