package at.jku.koppensteiner.androgios;


import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostComment;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.util.PostDataBuilder;

public class CommentDetailActivity extends AbstractModelActivity{
	
	private class CommentCommandsAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			return 2;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			TextView entry = new TextView(CommentDetailActivity.this);
			entry.setTextColor(Color.BLACK);
			entry.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			
			switch(position){
			case 0:
				entry.setText(R.string.chooseCommand);
				break;
			case 1:
				entry.setText(R.string.deleteComment);
				break;
			}
			
			return entry;
		}
		
	}
	
	private class StartCmdBtnListener implements OnClickListener{

		private final Spinner spinner;
		
		public StartCmdBtnListener(final Spinner spinner){
			this.spinner = spinner;
		}
		
		private DialogInterface.OnClickListener getStdListener(final String postData){
			return new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					String res = instance.sendCmd(postData);
					Toast.makeText(CommentDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			};
		}
		
		@Override
		public void onClick(View v) {
			AlertDialog.Builder alert = new AlertDialog.Builder(CommentDetailActivity.this);
			alert.setTitle(R.string.deleteComment);
			
			DialogInterface.OnClickListener posListener = null;
			DialogInterface.OnClickListener negListener = null;
			

			
			switch(spinner.getSelectedItemPosition()){
			case 0:
				return;
			case 1:
				alert.setMessage(R.string.deleteCommentRequest);
				if(serviceName.equals("")){
					posListener = getStdListener(PostDataBuilder.delHostComment(commentId));
				}else{
					posListener = getStdListener(PostDataBuilder.delSvcComment(commentId));
				}
				
				break;
			}
			
			negListener = new DialogInterface.OnClickListener() {
				  public void onClick(DialogInterface dialog, int whichButton) {
				    // nothing to implement
				  }
			};
			
			alert.setPositiveButton(R.string.ok, posListener);
			alert.setNegativeButton(R.string.cancel, negListener);
			alert.show();
			
		}
		
	}

	private class CommentDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private HostComment comment;
		private int size;
		
		public CommentDetailAdapter(){
			currentModel = instance.model;
			

			
			if(serviceName.equals("")){
				int location = currentModel.getHostCommentPosition(commentId);
				if(location>=0){
					comment = currentModel.hostComments.get(location);
					size = 8;
				}else{
					size = 1;
				}
				
			}else{
				int location = currentModel.getServiceCommentPosition(commentId);
				if(location>=0){
					comment = currentModel.serviceComments.get(location);
					size = 8;
				}else{
					size = 1;
				}
				
			}
			
		}
		
		@Override
		public int getCount() {
			return size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtHeader = new TextView(CommentDetailActivity.this);
			TextView txtData = new TextView(CommentDetailActivity.this);
			
			
			if(size ==1){
				txtHeader.setText(R.string.commentNotExisting);
				return txtHeader;
			}
			
			switch(position){
			case 0:
				if(serviceName.equals("")){
					txtHeader.setText(R.string.host);
					txtData.setText(hostName);
				}else{
					txtHeader.setText(getString(R.string.host) +" - "+getString(R.string.service));
					txtData.setText(hostName + " - " + serviceName);
				}
				
				break;
				
			case 1:
				txtHeader.setText(R.string.entryTime);
				txtData.setText(comment.entryTime);
				break;
				
			case 2:
				txtHeader.setText(R.string.author);
				txtData.setText(comment.author);
				break;
				
			case 3:
				txtHeader.setText(R.string.comment);
				txtData.setText(comment.comment);
				break;
				
			case 4:
				txtHeader.setText(R.string.commentID);
				txtData.setText(comment.commentId);
				break;
				
			case 5:
				txtHeader.setText(R.string.persistent);
				txtData.setText(comment.persistent);
				break;
				
			case 6:
				txtHeader.setText(R.string.type);
				txtData.setText(comment.type);
				break;
				
			case 7:
				txtHeader.setText(R.string.expires);
				txtData.setText(comment.expires);
				break;
			}
			
			LinearLayout ll = new LinearLayout(CommentDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	private String hostName;
	private String serviceName;
	private String commentId;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_cmd_layout);
		
		Bundle extras = getIntent().getExtras();
		hostName = extras.getString("HOSTNAME");
		serviceName = extras.getString("SERVICENAME");
		commentId = extras.getString("COMMENTID");
	 
		
		update();
	}

	@Override
	protected void update() {
		
		super.update();
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new CommentDetailAdapter());
		
		processManagementBar();
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_COMMENTS);
	}
	
	private void processManagementBar(){ 
		final Spinner spinner = ((Spinner)findViewById(R.id.spinnerCmds));
		spinner.setAdapter(new CommentCommandsAdapter());
		spinner.setSelection(0);
		
		Button btnGo = ((Button)findViewById(R.id.btnStartCmdDialog));
		btnGo.setOnClickListener(new StartCmdBtnListener(spinner));
	}
	

	
}
