package at.jku.koppensteiner.androgios;


import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
//import android.preference.RingtonePreference;
import android.preference.Preference.OnPreferenceChangeListener;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.service.PollingService;
import at.jku.koppensteiner.androgios.util.SSLHelper;
import at.jku.koppensteiner.androgios.util.TimePreference;

public class ConfigActivity extends PreferenceActivity{

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		
		addPreferencesFromResource(R.xml.config);
		
		init();
		
	}
	
	
	private void init(){
		
		final EditTextPreference nagiosUrl = (EditTextPreference) findPreference("configuration_nagios_url");
		nagiosUrl.setSummary(nagiosUrl.getText());
		
		nagiosUrl.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference pref,
					Object obj) {
				//update summary and baseUrl
				nagiosUrl.setSummary(obj.toString());
				MasterController.getInstance().getActiveNagiosInstance().baseUrl = obj.toString();
				return true;
			}
		});
		////////////////
		
		final EditTextPreference nagiosUser = (EditTextPreference) findPreference("configuration_nagios_username");
		nagiosUser.setSummary(nagiosUser.getText());
		
		nagiosUser.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference pref,
					Object obj) {
				//update summary and username
				nagiosUser.setSummary(obj.toString());
				MasterController.getInstance().getActiveNagiosInstance().username = obj.toString();
				return true;
			}
		});
		////////////////
		
		final EditTextPreference nagiosPass = (EditTextPreference) findPreference("configuration_nagios_password");
		nagiosPass.setSummary("****");
		
		nagiosPass.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference pref,
					Object obj) {
				//update password
				MasterController.getInstance().getActiveNagiosInstance().setPassword(obj.toString());
				return true;
			}
		});
		
		////////////////
		
		final CheckBoxPreference selfCert = (CheckBoxPreference) findPreference("configuration_acc_self_cert");
		selfCert.setSummary("");
		
		selfCert.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference pref,
					Object obj) {
				//set pref at instance
				MasterController.getInstance().getActiveNagiosInstance().acceptSelfSignedCert = (Boolean)obj;
				
				if((Boolean)obj){
					SSLHelper.trustAllHosts();
				}else{
					SSLHelper.trustDefaultHosts();
				}
				
				return true;
			}
		});
		////////////////
		
		final ListPreference pollInterval = (ListPreference) findPreference("configuration_poll_interval");
		
		pollInterval.setSummary(pollInterval.getEntry());
		
		pollInterval.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
			@Override
			public boolean onPreferenceChange(Preference pref,
					Object obj) {
				//set pref at instance
				MasterController.getInstance().getActiveNagiosInstance().pollIntervall = Integer.valueOf(obj.toString());
				pollInterval.setSummary(Integer.valueOf(obj.toString())/60 + " min");
				if(PollingService.running){
					MasterController.getInstance().restartService();
				}
				
				return true;
			}
		});
		
		////////////////
		
		final ListPreference dateFormat = (ListPreference) findPreference("configuration_date_format");
		
		dateFormat.setSummary(dateFormat.getEntry());
		
		dateFormat.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().getActiveNagiosInstance().dateFormat = newValue.toString();
				dateFormat.setSummary(newValue.toString());
				return true;
			}
			
		});
		
		////////////////
		
		final CheckBoxPreference sound = (CheckBoxPreference) findPreference("configuration_play_sound");
		
		sound.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().soundOnAlarm = (Boolean)newValue;
				return true;
			}
			
		});
		////////////////
		
		final CheckBoxPreference vibration = (CheckBoxPreference) findPreference("configuration_vibration");
		
		vibration.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().vibrateOnAlarm = (Boolean)newValue;
				return true;
			}
			
		});
		////////////////
		
		final CheckBoxPreference alarmOnUpdateFailed = (CheckBoxPreference)findPreference("configuration_alarm_on_update_failed");
		
		alarmOnUpdateFailed.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().alarmOnUpdateFailed = (Boolean)newValue;
				return true;
			}
			
		});
		
		////////////////
		
		final CheckBoxPreference useMobileNetwork = (CheckBoxPreference)findPreference("configuration_use_mobile_network");
		
		useMobileNetwork.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().useMobileNetwork = (Boolean)newValue;
				return true;
			}
			
		});
		
		////////////////
		
		final CheckBoxPreference pollFree = (CheckBoxPreference) findPreference("configuration_enable_poll_free_interval");
		
		pollFree.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setPollFreeIntervalEnabled((Boolean)newValue);
				return true;
			}
			
		});
		////////////////
		
		final TimePreference pollFreeStart = (TimePreference) findPreference("configuration_poll_free_start");
		
		pollFreeStart.setSummary(pollFreeStart.getText());
		
		pollFreeStart.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setPollFreeIntervalStart(newValue.toString());
				pollFreeStart.setSummary(newValue.toString());
				return true;
			}
			
		});
		////////////////
		
		final TimePreference pollFreeEnd = (TimePreference) findPreference("configuration_poll_free_end");
		
		pollFreeEnd.setSummary(pollFreeEnd.getText());
		
		pollFreeEnd.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setPollFreeIntervalEnd(newValue.toString());
				pollFreeEnd.setSummary(newValue.toString());
				return true;
			}
			
		});
		
		////////////////
		
		final CheckBoxPreference alarmFree = (CheckBoxPreference) findPreference("configuration_enable_alarm_free_interval");
		
		alarmFree.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setAlarmFreeIntervalEnabled((Boolean)newValue);
				return true;
			}
			
		});
		////////////////
		
		final TimePreference alarmFreeStart = (TimePreference) findPreference("configuration_alarm_free_start");
		alarmFreeStart.setSummary(alarmFreeStart.getText());
		alarmFreeStart.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setAlarmFreeIntervalStart(newValue.toString());
				alarmFreeStart.setSummary(newValue.toString());
				return true;
			}
			
		});
		////////////////
		
		final TimePreference alarmFreeEnd = (TimePreference) findPreference("configuration_alarm_free_end");
		
		alarmFreeEnd.setSummary(alarmFreeEnd.getText());
		
		alarmFreeEnd.setOnPreferenceChangeListener(new OnPreferenceChangeListener(){

			@Override
			public boolean onPreferenceChange(Preference preference,
					Object newValue) {
				MasterController.getInstance().setAlarmFreeIntervalEnd(newValue.toString());
				alarmFreeEnd.setSummary(newValue.toString());
				return true;
			}
			
		});
		
		
		
	}
	
}
