package at.jku.koppensteiner.androgios;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostDowntime;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.util.PostDataBuilder;


public class DowntimeDetailActivity extends AbstractModelActivity{
	
	private class DowntimeCommandsAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			return 2;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			TextView entry = new TextView(DowntimeDetailActivity.this);
			entry.setTextColor(Color.BLACK);
			entry.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			
			switch(position){
			case 0:
				entry.setText(R.string.chooseCommand);
				break;
			case 1:
				entry.setText(R.string.deleteDowntime);
				break;
			}
			
			return entry;
		}
		
	}
	
	private class StartCmdBtnListener implements OnClickListener{

		private final Spinner spinner;
		
		public StartCmdBtnListener(final Spinner spinner){
			this.spinner = spinner;
		}
		
		private DialogInterface.OnClickListener getStdListener(final String postData){
			return new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					String res = instance.sendCmd(postData);
					Toast.makeText(DowntimeDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			};
		}
		
		@Override
		public void onClick(View v) {
			AlertDialog.Builder alert = new AlertDialog.Builder(DowntimeDetailActivity.this);
			alert.setTitle(R.string.externalCommand);
			
			DialogInterface.OnClickListener posListener = null;
			DialogInterface.OnClickListener negListener = null;
			

			
			switch(spinner.getSelectedItemPosition()){
			case 0:
				return;
			case 1:
				alert.setMessage(R.string.deleteDowntimeRequest);
				if(serviceName.equals("")){
					posListener = getStdListener(PostDataBuilder.delHostDowntime(downtimeId));
				}else{
					posListener = getStdListener(PostDataBuilder.delSvcDowntime(downtimeId));
				}
				
				break;
			}
			
			negListener = new DialogInterface.OnClickListener() {
				  public void onClick(DialogInterface dialog, int whichButton) {
				    // nothing to implement
				  }
			};
			
			alert.setPositiveButton(R.string.ok, posListener);
			alert.setNegativeButton(R.string.cancel, negListener);
			alert.show();
			
		}
		
	}

	private class DowntimeDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private HostDowntime downtime;
		private int size;
		
		public DowntimeDetailAdapter(){
			currentModel = instance.model;
			
			
			
			if(serviceName.equals("")){
				int location = currentModel.getHostDowntimePosition(downtimeId);
				
				if(location >= 0){
					downtime = currentModel.hostDowntimes.get(location);
					size = 10;
				}else{
					size = 1;
				}
				
				
			}else{
				
				int location = currentModel.getServiceDowntimePosition(downtimeId);
				
				if(location >= 0){
					downtime = currentModel.serviceDowntimes.get(location);
					size = 10;
				}else{
					size = 1;
				}
				
				
			}
			
			
			
		}
		
		@Override
		public int getCount() {
			return size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtHeader = new TextView(DowntimeDetailActivity.this);
			TextView txtData = new TextView(DowntimeDetailActivity.this);
			
			
			if(size==1){
				txtHeader.setText(R.string.downtimeNotExisting);
				return txtHeader;
			}
			
			switch(position){
			case 0:
				if(serviceName.equals("")){
					txtHeader.setText(R.string.host);
					txtData.setText(hostName);
				}else{
					txtHeader.setText(R.string.host+" - "+R.string.service);
					txtData.setText(hostName + " - " + serviceName);
				}
				
				break;
				
			case 1:
				txtHeader.setText(R.string.entryTime);
				txtData.setText(downtime.entryTime);
				break;
				
			case 2:
				txtHeader.setText(R.string.author);
				txtData.setText(downtime.author);
				break;
				
			case 3:
				txtHeader.setText(R.string.comment);
				txtData.setText(downtime.comment);
				break;
				
			case 4:
				txtHeader.setText(R.string.startTime);
				txtData.setText(downtime.startTime);
				break;
				
			case 5:
				txtHeader.setText(R.string.endTime);
				txtData.setText(downtime.endTime);
				break;
				
			case 6:
				txtHeader.setText(R.string.type);
				txtData.setText(downtime.type);
				break;
				
			case 7:
				txtHeader.setText(R.string.duration);
				txtData.setText(downtime.duration);
				break;
				
			case 8:
				txtHeader.setText(R.string.downtimeID);
				txtData.setText(downtime.downtimeId);
				break;
				
			case 9:
				txtHeader.setText(R.string.triggerID);
				txtData.setText(downtime.triggerId);
				break;
			
			}
			
			LinearLayout ll = new LinearLayout(DowntimeDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	private String hostName;
	private String serviceName;
	private String downtimeId;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_cmd_layout);
		
		Bundle extras = getIntent().getExtras();
		hostName = extras.getString("HOSTNAME");
		serviceName = extras.getString("SERVICENAME");
		downtimeId = extras.getString("DOWNTIMEID");
		
		update();
	}

	@Override
	protected void update() {
		super.update();
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new DowntimeDetailAdapter());
		
		processManagementBar();
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_DOWNTIMES);
	}
	
	private void processManagementBar(){ 
		final Spinner spinner = ((Spinner)findViewById(R.id.spinnerCmds));
		spinner.setAdapter(new DowntimeCommandsAdapter());
		spinner.setSelection(0);
		
		Button btnGo = ((Button)findViewById(R.id.btnStartCmdDialog));
		btnGo.setOnClickListener(new StartCmdBtnListener(spinner)); 
	}


	
}
