package at.jku.koppensteiner.androgios;


import android.content.Intent;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostDowntime;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.ServiceDowntime;

public class DowntimesActivity extends AbstractModelActivity{

	private class DowntimesAdapter extends BaseAdapter{

		private int size;
		private MonitoringModel currentModel;
		
		public DowntimesAdapter(){
			currentModel = instance.model;
			size = instance.model.hostDowntimes.size()+instance.model.serviceDowntimes.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			
			TextView txtHeader = new TextView(DowntimesActivity.this);
			TextView txtDowntime = new TextView(DowntimesActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			
			if(size==0){
				txtHeader.setText(R.string.nothingToDisplay);
				return txtHeader;
			}
			
			HostDowntime downtime;
			if(position < currentModel.hostDowntimes.size()){
				downtime = currentModel.hostDowntimes.get(position);
				txtHeader.setText(downtime.hostName);
			}else{
				downtime = currentModel.serviceDowntimes.get(position - currentModel.hostDowntimes.size());
				txtHeader.setText(downtime.hostName + " - " + ((ServiceDowntime)downtime).serviceName);
			}
			
			txtDowntime.setText(downtime.startTime + " - " + downtime.endTime);
			
			LinearLayout ll = new LinearLayout(DowntimesActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtDowntime);
			return ll;
		}
		
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_DOWNTIMES);
	}

	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.DOWNTIMES)return;
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new DowntimesAdapter());
		list.setOnItemClickListener(getListItemListener());
		
	}
	
	private AdapterView.OnItemClickListener getListItemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				if( instance.model.hostDowntimes.size()+instance.model.serviceDowntimes.size()==0   )return;
				Intent intent = new Intent();
				HostDowntime downtime;
				if(pos < instance.model.hostDowntimes.size()){
					downtime = instance.model.hostDowntimes.get(pos);
					intent.putExtra("SERVICENAME", "");
				}else{
					downtime = instance.model.serviceDowntimes.get(pos - instance.model.hostDowntimes.size());
					intent.putExtra("SERVICENAME", ((ServiceDowntime)downtime).serviceName);
				}
				
				intent.putExtra("HOSTNAME", downtime.hostName);
				intent.putExtra("DOWNTIMEID", downtime.downtimeId);
				
				intent.setClass(MasterController.getInstance().getAppCtx(),DowntimeDetailActivity.class);
				startActivity(intent);
			}
		};
	}
	
}
