package at.jku.koppensteiner.androgios;


import android.content.Intent;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostComment;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;

public class HostCommentsActivity extends AbstractModelActivity{

	private class HostCommentsAdapter extends BaseAdapter{

		private int size;
		private MonitoringModel currentModel;
		
		public HostCommentsAdapter(){
			currentModel = instance.model;
			size = instance.model.hostComments.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			
			TextView txtHeader = new TextView(HostCommentsActivity.this);
			TextView txtComment = new TextView(HostCommentsActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);

			if(size==0){
				txtHeader.setText(R.string.nothingToDisplay);
				return txtHeader;
			}
			
			HostComment hostComment = currentModel.hostComments.get(position);
			
			txtHeader.setText(hostComment.hostName + ":");
			txtComment.setText(hostComment.comment);
			
			LinearLayout ll = new LinearLayout(HostCommentsActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtComment);
			return ll;
		}
		
	}
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}

	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_COMMENTS);
	}
	
	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.COMMENTS)return;
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new HostCommentsAdapter());
		list.setOnItemClickListener(getListITemListener());
	}
	
	private AdapterView.OnItemClickListener getListITemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				if(instance.model.hostComments.size()==0)return;
				HostComment hostComment = instance.model.hostComments.get(pos);
				Intent intent = new Intent();
				intent.putExtra("HOSTNAME", hostComment.hostName);
				intent.putExtra("SERVICENAME", "");
				intent.putExtra("COMMENTID", hostComment.commentId);
				intent.setClass(MasterController.getInstance().getAppCtx(),CommentDetailActivity.class);
				startActivity(intent);
			}
		};
	}
	
}
