package at.jku.koppensteiner.androgios;


import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.ScrollView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.util.DateTimePicker;
import at.jku.koppensteiner.androgios.util.PostDataBuilder;


public class HostDetailActivity extends AbstractModelActivity{

	private class HostCommandsAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			return 11;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName)); 
			TextView entry = new TextView(HostDetailActivity.this);
			entry.setTextColor(Color.BLACK);
			entry.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			
			switch(position){

			case 0:
				entry.setText(R.string.chooseCommand);
				break;
			case 1:
				entry.setText(R.string.rescheduleNextHostCheck);
				break;
			case 2:
				if(host.hostStatusDetail.contains("acknowledged")){
					entry.setText(R.string.removeProblemAcknowledgement);
				}else if(host.hostStatus.contains("DOWN")|| host.hostStatus.contains("UNREACHABLE")){
					entry.setText(R.string.acknowledgeHostProblem);
				}else{
					entry.setText(R.string.acknowledgeHostProblem);
					entry.setTextColor(Color.GRAY);
				}
				break;
			case 3:
				entry.setText(R.string.scheduleHostDowntime);
				break;
			case 4:
				entry.setText(R.string.disableNotificationsAllHostServices);
				break;
			case 5:
				entry.setText(R.string.enableNotificationsAllHostServices);
				break;
			case 6:
				entry.setText(R.string.scheduleCheckAllHostServices);
				break;
			case 7:
				entry.setText(R.string.disableChecksAllHostServices);
				break;
			case 8:
				entry.setText(R.string.enableChecksAllHostServices);
				break;
			case 9:
				entry.setText(R.string.addHostComment);
				break;
			case 10:
				entry.setText(R.string.deleteAllComments);
				break;
			}
			
			return entry;
		}
		
	}

	private class StartCmdBtnListener implements OnClickListener{

		private final Spinner spinner;
		
		public StartCmdBtnListener(final Spinner spinner){
			this.spinner = spinner;
		}
		
		private DialogInterface.OnClickListener getStdListener(final String postData){
			return new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					String res = instance.sendCmd(postData);
					Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			};
		}
		
		@Override
		public void onClick(View v) {
			
			AlertDialog.Builder alert = new AlertDialog.Builder(HostDetailActivity.this);
			alert.setTitle(R.string.externalCommand);
			
			Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));
			DialogInterface.OnClickListener posListener = null;
			DialogInterface.OnClickListener negListener = null;
			LinearLayout ll;
			
			switch(spinner.getSelectedItemPosition()){
				
			case 0:
				return;
			case 1:
				
				alert.setMessage(R.string.scheduleHostCheckRequest);

				ll = new LinearLayout(HostDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtCheckTimeLabel = new TextView(HostDetailActivity.this);
				final CheckBox cbForce = new CheckBox(HostDetailActivity.this);
				final DateTimePicker dtp = new DateTimePicker(HostDetailActivity.this);
				
				txtCheckTimeLabel.setText(R.string.checkTime);
				cbForce.setText(R.string.forceCheck);
				cbForce.setChecked(true);
				
				ll.addView(txtCheckTimeLabel); 
				ll.addView(dtp);
				ll.addView(cbForce);
				alert.setView(ll);

				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String checkTime = dtp.getDateString(instance.dateFormat);
						boolean force = cbForce.isChecked();
						String postData = PostDataBuilder.scheduleHostCheck(hostName, checkTime, force);
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				
				
				break;
			case 2:
				if(host.hostStatusDetail.contains("acknowledged")){
					alert.setMessage(R.string.removeHostProblemAcknowledgementRequest);
					posListener = getStdListener(PostDataBuilder.removeHostAcknoledgement(hostName));
					
				}else if(host.hostStatus.contains("DOWN")|| host.hostStatus.contains("UNREACHABLE")){
					alert.setMessage(R.string.acknoledgeHostProblemRequest);
					
					ll = new LinearLayout(HostDetailActivity.this);
					ll.setOrientation(LinearLayout.VERTICAL);
					
					final TextView txtCommentLabel = new TextView(HostDetailActivity.this);
					final EditText txtComment = new EditText(HostDetailActivity.this);
					final CheckBox cbSticky = new CheckBox(HostDetailActivity.this);
					final CheckBox cbSendNotification = new CheckBox(HostDetailActivity.this);
					final CheckBox cbPersistentComment = new CheckBox(HostDetailActivity.this);
					
					txtCommentLabel.setText(R.string.comment);
					cbSticky.setText(R.string.stickyAcknowledgement);
					cbSticky.setChecked(true);
					cbSendNotification.setText(R.string.sendNotification);
					cbSendNotification.setChecked(true);
					cbPersistentComment.setText(R.string.persistentComment);
					cbPersistentComment.setChecked(false);
					
					ll.addView(txtCommentLabel);
					ll.addView(txtComment);
					ll.addView(cbSticky);
					ll.addView(cbSendNotification);
					ll.addView(cbPersistentComment);
					alert.setView(ll);
					
					posListener = new DialogInterface.OnClickListener() {

						@Override
						public void onClick(DialogInterface dialog, int which) {
							String comment = txtComment.getText().toString();
							String postData = PostDataBuilder.acknowledgeHostProblem(hostName, instance.username, comment, 
									cbSticky.isChecked(), cbSendNotification.isChecked(), cbPersistentComment.isChecked());
							String res = instance.sendCmd(postData);
							Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
						}
							
					};
				}else{
					alert.setMessage(R.string.noProblemToAck);
					posListener = new DialogInterface.OnClickListener() {

						@Override
						public void onClick(DialogInterface dialog, int which) {
							// nothing to implement
						}
							
					};
				}
				break;
			case 3:
				alert.setMessage(R.string.scheduleHostDowntimeRequest);
				
				
				ScrollView sv = new ScrollView(HostDetailActivity.this);
				ll = new LinearLayout(HostDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtCommentLabel = new TextView(HostDetailActivity.this);
				final EditText txtComment = new EditText(HostDetailActivity.this);
				final TextView txtStartTimeLabel = new TextView(HostDetailActivity.this);
				final DateTimePicker dtpStartTime = new DateTimePicker(HostDetailActivity.this);
				final TextView txtEndTimeLabel = new TextView(HostDetailActivity.this);
				final DateTimePicker dtpEndTime = new DateTimePicker(HostDetailActivity.this);
				
				final Spinner spType = new Spinner(HostDetailActivity.this);
				
				final TextView txtHoursLabel = new TextView(HostDetailActivity.this);
				final EditText txtHours = new EditText(HostDetailActivity.this);
				final TextView txtMinutesLabel = new TextView(HostDetailActivity.this);
				final EditText txtMinutes = new EditText(HostDetailActivity.this);
				
				final Spinner spChildHosts = new Spinner(HostDetailActivity.this);
				
				
				
				txtCommentLabel.setText(R.string.comment);
				txtStartTimeLabel.setText(R.string.startTime);
				txtEndTimeLabel.setText(R.string.endTime);
				
				spType.setAdapter(ArrayAdapter.createFromResource(HostDetailActivity.this, R.array.downtimeTypes, android.R.layout.simple_spinner_item));
				spType.setSelection(1);
				txtHoursLabel.setText(R.string.ifFlexibleHours);
				txtMinutesLabel.setText(R.string.ifFlexibleMinutes);
				spChildHosts.setAdapter(ArrayAdapter.createFromResource(HostDetailActivity.this, R.array.downtimeChildHosts, android.R.layout.simple_spinner_item));
				
				ll.addView(txtCommentLabel);
				ll.addView(txtComment);
				ll.addView(txtStartTimeLabel);
				ll.addView(dtpStartTime);
				ll.addView(txtEndTimeLabel);
				ll.addView(dtpEndTime);
				ll.addView(spType);
				ll.addView(txtHoursLabel);
				ll.addView(txtHours);
				ll.addView(txtMinutesLabel);
				ll.addView(txtMinutes);
				ll.addView(spChildHosts);
				
				sv.addView(ll);
				alert.setView(sv);
				
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String comment = txtComment.getText().toString();
						String startTime = dtpStartTime.getDateString(instance.dateFormat);
						String endTime = dtpEndTime.getDateString(instance.dateFormat);
						int childOptions = spChildHosts.getSelectedItemPosition();
						int type = spType.getSelectedItemPosition();
						String hours = txtHours.getText().toString();
						String minutes = txtMinutes.getText().toString();
						String postData = PostDataBuilder.scheduleHostDowntime(hostName, instance.username, comment, 
								startTime, endTime, childOptions, type, hours, minutes);
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 4:
				alert.setMessage(R.string.disableNotificationsAllHostServicesRequest);
				
				final CheckBox cbDisableHost = new CheckBox(HostDetailActivity.this);
				cbDisableHost.setText(R.string.disableForHostToo);
				cbDisableHost.setChecked(false);
				
				alert.setView(cbDisableHost);
				
				posListener = new DialogInterface.OnClickListener() {
					
					@Override
					public void onClick(DialogInterface dialog, int which) {
						String postData = PostDataBuilder.disableHostSvcNotifications(hostName, cbDisableHost.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 5:
				alert.setMessage(R.string.enableNotificationsAllHostServicesRequest);
				
				final CheckBox cbEnableHost = new CheckBox(HostDetailActivity.this);
				cbEnableHost.setText(R.string.enableForHostToo);
				cbEnableHost.setChecked(false);
				
				alert.setView(cbEnableHost);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String postData = PostDataBuilder.enableHostSvcNotifications(hostName, cbEnableHost.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 6:
				alert.setMessage(R.string.scheduleCheckAllHostServicesRequest);
				
				ll = new LinearLayout(HostDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtSvcCheckTimeLabel = new TextView(HostDetailActivity.this);
				final DateTimePicker dtpSvcCheckTime = new DateTimePicker(HostDetailActivity.this);
				final CheckBox cbSvcForce = new CheckBox(HostDetailActivity.this);
				
				txtSvcCheckTimeLabel.setText(R.string.checkTime);
				cbSvcForce.setText(R.string.forceCheck);
				cbSvcForce.setChecked(false);
				
				ll.addView(txtSvcCheckTimeLabel);
				ll.addView(dtpSvcCheckTime);
				ll.addView(cbSvcForce);
				alert.setView(ll);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String time = dtpSvcCheckTime.getDateString(instance.dateFormat);
						String postData = PostDataBuilder.scheduleHostSvcChecks(hostName, time, cbSvcForce.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 7:
				alert.setMessage(R.string.disableChecksAllHostServicesRequest);
				
				final CheckBox cbDisSvcChecksHost = new CheckBox(HostDetailActivity.this);
				cbDisSvcChecksHost.setText(R.string.disableForHostToo);
				cbDisSvcChecksHost.setChecked(false);
				
				alert.setView(cbDisSvcChecksHost);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String postData = PostDataBuilder.disableHostSvcChecks(hostName, cbDisSvcChecksHost.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 8:
				alert.setMessage(R.string.enableChecksAllHostServicesRequest);
				
				final CheckBox cbEnaSvcChecksHost = new CheckBox(HostDetailActivity.this);
				cbEnaSvcChecksHost.setText(R.string.enableForHostToo);
				cbEnaSvcChecksHost.setChecked(false);
				
				alert.setView(cbEnaSvcChecksHost);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String postData = PostDataBuilder.enableHostSvcChecks(hostName, cbEnaSvcChecksHost.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				}; 
				break;
			case 9:
				alert.setMessage(R.string.addHostCommentRequest);
				
				ll = new LinearLayout(HostDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtHostCommentLabel = new TextView(HostDetailActivity.this);
				final EditText txtHostComment = new EditText(HostDetailActivity.this);
				final CheckBox cbPersistent = new CheckBox(HostDetailActivity.this);
				
				txtHostCommentLabel.setText(R.string.comment);
				cbPersistent.setText(R.string.persistent);
				cbPersistent.setChecked(true);
				
				ll.addView(txtHostCommentLabel);
				ll.addView(txtHostComment);
				ll.addView(cbPersistent);
				alert.setView(ll);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String comment = txtHostComment.getText().toString();
						String postData = PostDataBuilder.addHostComment(hostName, instance.username, comment, cbPersistent.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 10:
				alert.setMessage(R.string.deleteAllHostCommentsRequest);
				posListener = getStdListener(PostDataBuilder.delAllHostComments(hostName));
				break;
			}//end switch
			
			
			negListener = new DialogInterface.OnClickListener() {
				  public void onClick(DialogInterface dialog, int whichButton) {
				    // nothing to implement
				  }
			};
			
			alert.setPositiveButton(R.string.ok, posListener);
			alert.setNegativeButton(R.string.cancel, negListener);
			alert.show();
			
		}
		
	}
	
	private class HostDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		Host host;
		int size;
		
		public HostDetailAdapter(){
			currentModel = instance.model;
			int pos = currentModel.getHostPosition(hostName);
			
			if(pos >= 0){
				size = 19;
				host = currentModel.hosts.get(currentModel.getHostPosition(hostName));
			}else{
				size = 0;
			}
			
		}
		
		@Override
		public int getCount() {
			return size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			LinearLayout ll = new LinearLayout(HostDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			TextView txtHeader = new TextView(HostDetailActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			TextView txtData = new TextView(HostDetailActivity.this);
			
			
			switch(position){
			case 0:
				txtHeader.setText(R.string.hostStatus);
				txtData.setText(host.hostStatusDetail);
				break;
			case 1:
				txtHeader.setText(R.string.statusInformation);
				txtData.setText(host.statusInformation);
				break;
			case 2:
				txtHeader.setText(R.string.performanceData);
				txtData.setText(host.performanceData);
				break;
			case 3:
				txtHeader.setText(R.string.currentAttempt);
				txtData.setText(host.currentAttempt);
				break;
			case 4:
				txtHeader.setText(R.string.lastCheckTime);
				txtData.setText(host.lastCheckTime);
				break;
			case 5:
				txtHeader.setText(R.string.checkType);
				txtData.setText(host.checkType);
				break;
			case 6:
				txtHeader.setText(R.string.checkLatency);
				txtData.setText(host.checkLatencyDuration);
				break;
			case 7:
				txtHeader.setText(R.string.nextScheduledActiveCheck);
				txtData.setText(host.nextScheduledActiveCheck);
				break;
			case 8:
				txtHeader.setText(R.string.lastStateChange);
				txtData.setText(host.lastStateChange);
				break;
			case 9:
				txtHeader.setText(R.string.lastNotification);
				txtData.setText(host.lastNotification);
				break;
			case 10:
				txtHeader.setText(R.string.isThisHostFlapping);
				txtData.setText(host.isThisHostFlapping);
				break;
			case 11:
				txtHeader.setText(R.string.inScheduledDowntime);
				txtData.setText(host.inScheduledDowntime);
				break;
			case 12:
				txtHeader.setText(R.string.lastUpdate);
				txtData.setText(host.lastUpdate);
				break;
			case 13:
				txtHeader.setText(R.string.activeChecks);
				txtData.setText(host.activeChecks);
				break;
			case 14:
				txtHeader.setText(R.string.passiveChecks);
				txtData.setText(host.passiveChecks);
				break;
			case 15:
				txtHeader.setText(R.string.obsessing);
				txtData.setText(host.obsessing);
				break;
			case 16:
				txtHeader.setText(R.string.notifications);
				txtData.setText(host.notifications);
				break;
			case 17:
				txtHeader.setText(R.string.eventHandler);
				txtData.setText(host.eventHandler);
				break;
			case 18:
				txtHeader.setText(R.string.flapDetection);
				txtData.setText(host.flapDetection);
				break;
			}
			
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	
	
	private String hostName;

	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_cmd_layout);
		
		
		Bundle extras = getIntent().getExtras();
		hostName = extras.getString("HOSTNAME");
		if(!extras.getBoolean("POLLED", false) && 
				instance.model.hosts.get(instance.model.getHostPosition(hostName)).hostStatusDetail.equals("")){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_HOSTDETAIL + hostName.replace(" ", "+"));
	}

	@Override
	protected void update() {
		
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.HOSTDETAIL)return;
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new HostDetailAdapter());
		list.setOnItemClickListener(getModelListItemListener());
		
		processManagementControls();
	}
	
	private void processManagementControls(){ 
		
		final Spinner spinner = ((Spinner)findViewById(R.id.spinnerCmds));
		spinner.setAdapter(new HostCommandsAdapter());
		spinner.setSelection(0);
		
		Button btnGo = ((Button)findViewById(R.id.btnStartCmdDialog));
		btnGo.setOnClickListener(new StartCmdBtnListener(spinner));
		
		
	}
	
	private AdapterView.OnItemClickListener getModelListItemListener(){
		
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));
				String res = "";
				
				switch(pos){
				case 13:
					if(host.activeChecks.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableHostCheck(hostName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableHostCheck(hostName));
					}
					break;
				case 14:
					if(host.passiveChecks.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disablePassiveHostChecks(hostName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enablePassiveHostChecks(hostName));
					}
					break;
				case 15:
					if(host.obsessing.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.stopObsessingOverHost(hostName));
					}else{
						res = instance.sendCmd(PostDataBuilder.startObsessingOverHost(hostName));
					}
					break;
				case 16:
					AlertDialog.Builder alert = new AlertDialog.Builder(HostDetailActivity.this);
					alert.setTitle(R.string.externalCommand);
					
					if(host.notifications.contains("ENABLED")){
						alert.setMessage(R.string.disableNotificationsRequest);
						
						final CheckBox cbChildHosts = new CheckBox(HostDetailActivity.this);
						cbChildHosts.setText(R.string.disableNotificationsChildHosts);
						cbChildHosts.setChecked(false);
						alert.setView(cbChildHosts);
						alert.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {

							@Override
							public void onClick(DialogInterface dialog, int which) {
								String postData = PostDataBuilder.disableHostNotifications(hostName, cbChildHosts.isChecked());
								String res = instance.sendCmd(postData);
								Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
							}
								
						});
						
					}else{
						alert.setMessage(R.string.enableNotificationsRequest);
						
						final CheckBox cbChildHosts = new CheckBox(HostDetailActivity.this);
						cbChildHosts.setText(R.string.enableNotificationsChildHosts);
						cbChildHosts.setChecked(false);
						alert.setView(cbChildHosts);
						alert.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {

							@Override
							public void onClick(DialogInterface dialog, int which) {
								String postData = PostDataBuilder.enableHostNotifications(hostName, cbChildHosts.isChecked());
								String res = instance.sendCmd(postData);
								Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
							}
								
						});
					}
					
					alert.setNegativeButton(R.string.cancel, null);
					alert.show();
					break;
				case 17:
					if(host.eventHandler.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableHostEventHandler(hostName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableHostEventHandler(hostName));
					}
					break;
				case 18:
					if(host.flapDetection.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableHostFlapDetection(hostName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableHostFlapDetection(hostName));
					}
					break;
					
				}//switch
				if(!res.equals("")){
					Toast.makeText(HostDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			}
			
		};
	}
	
	
	

	
}
