package at.jku.koppensteiner.androgios;


import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;

public class HostListActivity extends AbstractModelActivity{

	
	private class HostListAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private int size;
		
		public HostListAdapter(){
			currentModel = instance.model;
			size = instance.model.hosts.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtHostStatus = new TextView(HostListActivity.this);
			
			if(size==0){
				txtHostStatus.setText(R.string.nothingToDisplay);
				txtHostStatus.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
				return txtHostStatus;
			}
			
			String status = currentModel.hosts.get(position).hostStatus;
			txtHostStatus.setText(currentModel.hosts.get(position).hostName + " - " + status);
			txtHostStatus.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			
			
			
			if(status.contains("DOWN")||status.contains("UNREACHABLE")){
				txtHostStatus.setTextColor(Color.RED);
			}else if(status.contains("UP")){
				txtHostStatus.setTextColor(Color.GREEN);
			}else{
				txtHostStatus.setTextColor(Color.GRAY);
			}
			
			LinearLayout ll = new LinearLayout(HostListActivity.this);
			ll.addView(txtHostStatus);
			return ll;
		}
		
	}
	

	private boolean filtered;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		
		filtered = getIntent().getBooleanExtra("FILTERED", false);
		
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}
	
	@Override
	protected void poll(){
		super.poll();
	    if(filtered){
			Bundle extras = getIntent().getExtras();
			int statusTypeParam = extras.getInt("HOSTSTATUSTYPES");
			int propsParam = extras.getInt("HOSTPROPS");
			
			instance.poll(NagiosInstance.URL_HOSTLIST + "&hoststatustypes=" + statusTypeParam + "&hostprops=" + propsParam);
		}else{
			instance.poll(NagiosInstance.URL_HOSTLIST);
		}                   
	}
	
	@Override
	protected void update(){
		
		super.update();
		
		if((filtered && instance.model.lastParsed != MonitoringModel.HOSTLISTFILTERED || 
				!filtered && instance.model.lastParsed != MonitoringModel.HOSTLIST) && 
				instance.model.lastParsed != MonitoringModel.HOSTDETAIL)return; 
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		
		list.setAdapter(new HostListAdapter());
		
		
		list.setOnItemClickListener(getListItemListener());
		
	}
	
	
	private AdapterView.OnItemClickListener getListItemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				if(instance.model.hosts.size()==0
						||instance.model.hosts.get(pos).hostStatus.contains("PENDING"))return;
				
				String hostName = instance.model.hosts.get(pos).hostName;
				Intent intent = new Intent();
				intent.putExtra("HOSTNAME", hostName);
				intent.setClass(MasterController.getInstance().getAppCtx(), HostDetailActivity.class);
				startActivity(intent);
			}
		};
	}
	
	
}
