package at.jku.koppensteiner.androgios;

import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Outage;

public class OutageDetailActivity extends AbstractModelActivity{

	private class OutageDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private Outage outage;
		private int size;
		
		public OutageDetailAdapter(){
			currentModel = instance.model;
			
			int location = currentModel.getOutagePosition(hostName); 
			if(location >= 0){
				outage = currentModel.outages.get(location);
				size = 7;
			}else{
				size = 1;
			}
			
		}
		
		@Override
		public int getCount() {
			return size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtHeader = new TextView(OutageDetailActivity.this);
			TextView txtData = new TextView(OutageDetailActivity.this);
			
			
			if(size == 1){
				txtHeader.setText(R.string.outageNotExisting);
				return txtHeader;
			}
			
			switch(position){
			case 0:
				txtHeader.setText(R.string.severity);
				txtData.setText(outage.severity);
				break;
				
			case 1:
				txtHeader.setText(R.string.host);
				txtData.setText(outage.host);
				break;
				
			case 2:
				txtHeader.setText(R.string.state);
				txtData.setText(outage.state);
				break;
				
			case 3:
				txtHeader.setText(R.string.notes);
				txtData.setText(outage.notes);
				break;
				
			case 4:
				txtHeader.setText(R.string.stateDuration);
				txtData.setText(outage.stateDuration);
				break;
				
			case 5:
				txtHeader.setText(R.string.nrHostsAffected);
				txtData.setText(outage.nrHostsAffected);
				break;
				
			case 6:
				txtHeader.setText(R.string.nrServicesAffected);
				txtData.setText(outage.nrServicesAffected);
				break;
			}
			
			LinearLayout ll = new LinearLayout(OutageDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	private String hostName;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		
		Bundle extras = getIntent().getExtras();
		hostName = extras.getString("HOSTNAME");
		
		update();
	}

	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_OUTAGES);
	}
	
	@Override
	protected void update() {
		super.update();
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new OutageDetailAdapter());
		
	}
}
