package at.jku.koppensteiner.androgios;


import android.content.Intent;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Outage;

public class OutagesActivity extends AbstractModelActivity{

	private class OutagesAdapter extends BaseAdapter{

		private int size;
		private MonitoringModel currentModel;
		
		public OutagesAdapter(){
			currentModel = instance.model;
			size = instance.model.outages.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			
			TextView txtHeader = new TextView(OutagesActivity.this);
			TextView txtData = new TextView(OutagesActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);

			if(size==0){
				txtHeader.setText(R.string.nothingToDisplay);
				return txtHeader;
			}
			
			Outage outage = currentModel.outages.get(position);
			
			txtHeader.setText(outage.host + ":");
			txtData.setText(getString(R.string.nrHostsAffected) + ": " + outage.nrHostsAffected + "\n" 
					+ getString(R.string.nrServicesAffected) + ": " + outage.nrServicesAffected);
			
			LinearLayout ll = new LinearLayout(OutagesActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}

	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_OUTAGES);
	}
	
	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.OUTAGES)return;
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new OutagesAdapter());
		list.setOnItemClickListener(getListItemListener());
	}
	
	private AdapterView.OnItemClickListener getListItemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				if(instance.model.outages.size()==0)return;
				Outage outage = instance.model.outages.get(pos);
				Intent intent = new Intent();
				intent.putExtra("HOSTNAME", outage.host);
				intent.setClass(MasterController.getInstance().getAppCtx(), OutageDetailActivity.class);
				startActivity(intent);
			}
		};
	}
}
