package at.jku.koppensteiner.androgios;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Process;
import at.jku.koppensteiner.androgios.util.PostDataBuilder;

public class ProcessDetailActivity extends AbstractModelActivity{
	
	private class ProcessCommandsAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			return 3;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			TextView entry = new TextView(ProcessDetailActivity.this);
			entry.setTextColor(Color.BLACK);
			entry.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			
			switch(position){
			case 0:
				entry.setText(R.string.chooseCommand);
				break;
			case 1:
				entry.setText(R.string.restartNagiosProcess);
				break;
			case 2:
				entry.setText(R.string.shutdownNagiosProcess);
				break;
			}
			
			return entry;
		}
		
	}
	
	private class StartCmdBtnListener implements OnClickListener{

		private final Spinner spinner;
		
		public StartCmdBtnListener(final Spinner spinner){
			this.spinner = spinner;
		}
		
		private DialogInterface.OnClickListener getStdListener(final String postData){
			return new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					String res = instance.sendCmd(postData);
					Toast.makeText(ProcessDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			};
		}
		
		@Override
		public void onClick(View v) {
			AlertDialog.Builder alert = new AlertDialog.Builder(ProcessDetailActivity.this);
			alert.setTitle(R.string.externalCommand);
			
			DialogInterface.OnClickListener posListener = null;
			DialogInterface.OnClickListener negListener = null;
			

			
			switch(spinner.getSelectedItemPosition()){
			case 0:
				return;
			case 1:
				alert.setMessage(R.string.restartNagiosProcessRequest);
				posListener = getStdListener(PostDataBuilder.restartProgram());
				break;
			case 2:
				alert.setMessage(R.string.shutdownNagiosProcessRequest);
				posListener = getStdListener(PostDataBuilder.shutdownProgram());
				break;
				
				
			}
			
			negListener = new DialogInterface.OnClickListener() {
				  public void onClick(DialogInterface dialog, int whichButton) {
				    // nothing to implement
				  }
			};
			
			alert.setPositiveButton(R.string.ok, posListener);
			alert.setNegativeButton(R.string.cancel, negListener);
			alert.show();
			
		}
		
	}

	private class ProcessDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		
		public ProcessDetailAdapter(){
			currentModel = instance.model;
		}
		
		@Override
		public int getCount() {
			return 16;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			LinearLayout ll = new LinearLayout(ProcessDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			TextView txtHeader = new TextView(ProcessDetailActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			TextView txtData = new TextView(ProcessDetailActivity.this); 
			Process process = currentModel.process;
			
			switch(position){
			case 0:
				txtHeader.setText(R.string.programVersion);
				txtData.setText(process.programVersion);
				break;
			case 1:
				txtHeader.setText(R.string.programStartTime);
				txtData.setText(process.programStartTime);
				break;
			case 2:
				txtHeader.setText(R.string.totalRunningTime);
				txtData.setText(process.totalRunningTime);
				break;
			case 3:
				txtHeader.setText(R.string.lastExternalCommandCheck);
				txtData.setText(process.lastExternalCommandCheck);
				break;
			case 4:
				txtHeader.setText(R.string.lastLogFileRotation);
				txtData.setText(process.lastLogFileRotation);
				break;
			case 5:
				txtHeader.setText(R.string.nagiosPid);
				txtData.setText(process.nagiosPID);
				break;
			case 6:
				txtHeader.setText(R.string.notificationsEnabled);
				txtData.setText(process.notificationsEnabled);
				break;
			case 7:
				txtHeader.setText(R.string.serviceChecksBeingExecuted);
				txtData.setText(process.serviceChecksBeingExecuted);
				break;
			case 8:
				txtHeader.setText(R.string.passiveServiceChecksBeingAccepted);
				txtData.setText(process.passiveServiceChecksBeingAccepted);
				break;
			case 9:
				txtHeader.setText(R.string.hostChecksBeingExecuted);
				txtData.setText(process.hostChecksBeingExecuted);
				break;
			case 10:
				txtHeader.setText(R.string.passiveHostChecksBeingAccepted);
				txtData.setText(process.passiveHostChecksBeingAccepted);
				break;
			case 11:
				txtHeader.setText(R.string.eventHandlersEnabled);
				txtData.setText(process.eventHandlersEnabled);
				break;
			case 12:
				txtHeader.setText(R.string.obsessingOverServices);
				txtData.setText(process.obsessingOverServices);
				break;
			case 13:
				txtHeader.setText(R.string.obsessingOverHosts);
				txtData.setText(process.obsessingOverHosts);
				break;
			case 14:
				txtHeader.setText(R.string.flapDetectionEnabled);
				txtData.setText(process.flapDetectionEnabled);
				break;
			case 15:
				txtHeader.setText(R.string.performanceDataBeingProcessed);
				txtData.setText(process.performanceDataBeingProcessed);
				break;
			
			}
			
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_cmd_layout);
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_NAGIOSPROCESS);
	}

	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.NAGIOSPROCESS)return;
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new ProcessDetailAdapter());
		
		list.setOnItemClickListener(getModelListItemListener());
		
		processManagementBar();
		
	}
	
	private AdapterView.OnItemClickListener getModelListItemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				String res = "";
				
				switch(pos){
				case 6:
					if(instance.model.process.notificationsEnabled.contains("YES")){
						res = instance.sendCmd(PostDataBuilder.disableNotifications());
					}else{
						res = instance.sendCmd(PostDataBuilder.enableNotifications());
					}
					break;
				case 7:
					if(instance.model.process.serviceChecksBeingExecuted.contains("YES")){
						res = instance.sendCmd(PostDataBuilder.stopExecutingSvcChecks());
					}else{
						res = instance.sendCmd(PostDataBuilder.startExecutingSvcChecks());
					}
					break;
				case 8:
					if(instance.model.process.passiveServiceChecksBeingAccepted.contains("YES")){
						res = instance.sendCmd(PostDataBuilder.stopAcceptingPassiveSvcChecks());
					}else{
						res = instance.sendCmd(PostDataBuilder.startAcceptingPassiveSvcChecks());
					}
					break;
				case 9:
					if(instance.model.process.hostChecksBeingExecuted.contains("YES")){
						res = instance.sendCmd(PostDataBuilder.stopExecutingHostChecks());
					}else{
						res = instance.sendCmd(PostDataBuilder.startExecutingHostChecks());
					}
					break;
				case 10:
					if(instance.model.process.passiveHostChecksBeingAccepted.contains("YES")){
						res = instance.sendCmd(PostDataBuilder.stopAcceptingPassiveHostChecks());
					}else{
						res = instance.sendCmd(PostDataBuilder.startAcceptingPassiveHostChecks());
					}
					break;
				case 11:
					if(instance.model.process.eventHandlersEnabled.contains("Yes")){
						res = instance.sendCmd(PostDataBuilder.disableEventHandlers());
					}else{
						res = instance.sendCmd(PostDataBuilder.enableEventHandlers());
					}
					break;
				case 12:
					if(instance.model.process.obsessingOverServices.contains("Yes")){
						res = instance.sendCmd(PostDataBuilder.stopObsessingOverSvc());
					}else{
						res = instance.sendCmd(PostDataBuilder.startObsessingOverSvc());
					}
					break;
				case 13:
					if(instance.model.process.obsessingOverHosts.contains("Yes")){
						res = instance.sendCmd(PostDataBuilder.stopObsessingOverHost());
					}else{
						res = instance.sendCmd(PostDataBuilder.startObsessingOverHost());
					}
					break;
				case 14:
					if(instance.model.process.flapDetectionEnabled.contains("Yes")){
						res = instance.sendCmd(PostDataBuilder.disableFlapDetection());
					}else{
						res = instance.sendCmd(PostDataBuilder.enableFlapDetection());
					}
					break;
				case 15:
					if(instance.model.process.performanceDataBeingProcessed.contains("Yes")){
						res = instance.sendCmd(PostDataBuilder.disablePerformanceData());
					}else{
						res = instance.sendCmd(PostDataBuilder.enablePerformanceData());
					}
					break;
				}
				
				if(!res.equals("")){
					Toast.makeText(ProcessDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
			}
			
		};
	}
	
	private void processManagementBar(){ 
		final Spinner spinner = ((Spinner)findViewById(R.id.spinnerCmds));
		spinner.setAdapter(new ProcessCommandsAdapter());
		spinner.setSelection(0);
		
		Button btnGo = ((Button)findViewById(R.id.btnStartCmdDialog));
		btnGo.setOnClickListener(new StartCmdBtnListener(spinner)); 
	}
	

	
}
