package at.jku.koppensteiner.androgios;


import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.ScrollView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Service;
import at.jku.koppensteiner.androgios.util.DateTimePicker;
import at.jku.koppensteiner.androgios.util.PostDataBuilder;

public class ServiceDetailActivity extends AbstractModelActivity{
	
	private class ServiceCommandsAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			return 6;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));  
			Service service = host.hostServices.get(host.getServicePosition(serviceName));
			
			TextView entry = new TextView(ServiceDetailActivity.this);
			entry.setTextColor(Color.BLACK);
			entry.setTextSize(TypedValue.COMPLEX_UNIT_PT, 8);
			
			switch(position){
			case 0:
				entry.setText(R.string.chooseCommand);
				break;
			case 1:
				entry.setText(R.string.rescheduleNextServiceCheck);
				break;
			case 2:
				if(service.currentStatusDetail.contains("acknowledged")){
					entry.setText(R.string.removeProblemAcknowledgement);
				}else if(service.currentStatus.contains("CRITICAL") || 
						service.currentStatus.contains("WARNING") || 
						service.currentStatus.contains("UNKNOWN")){ 
					entry.setText(R.string.acknowledgeServiceProblem);
				}else{
					entry.setText(R.string.acknowledgeServiceProblem);
					entry.setTextColor(Color.GRAY);
				}
				break;
			case 3:
				entry.setText(R.string.scheduleServiceDowntime);
				break;
			case 4:
				entry.setText(R.string.addServiceComment);
				break;
			case 5:
				entry.setText(R.string.deleteAllComments);
				break;
			}
			
			return entry;
		}
		
	}
	
	private class StartCmdBtnListener implements OnClickListener{
		
		private final Spinner spinner;
		
		public StartCmdBtnListener(final Spinner spinner){
			this.spinner = spinner;
		}
		
		private DialogInterface.OnClickListener getStdListener(final String postData){
			return new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					String res = instance.sendCmd(postData);
					Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			};
		}

		@Override
		public void onClick(View v) {
			
			AlertDialog.Builder alert = new AlertDialog.Builder(ServiceDetailActivity.this);
			alert.setTitle(R.string.externalCommand);
			
			Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));
			Service service = host.hostServices.get(host.getServicePosition(serviceName));
			
			DialogInterface.OnClickListener posListener = null;
			DialogInterface.OnClickListener negListener = null;
			LinearLayout ll;
			
			switch(spinner.getSelectedItemPosition()){

			case 0:
				return;
			case 1:
				alert.setMessage(R.string.scheduleServiceCheckRequest);
				 
				ll = new LinearLayout(ServiceDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtCheckTimeLabel = new TextView(ServiceDetailActivity.this);
				final DateTimePicker dtpCheckTime = new DateTimePicker(ServiceDetailActivity.this);
				final CheckBox cbForce = new CheckBox(ServiceDetailActivity.this);
				
				txtCheckTimeLabel.setText(R.string.checkTime);
				cbForce.setText(R.string.forceCheck);
				cbForce.setChecked(true);
				
				ll.addView(txtCheckTimeLabel);
				ll.addView(dtpCheckTime);
				ll.addView(cbForce);
				alert.setView(ll); 

				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String checkTime = dtpCheckTime.getDateString(instance.dateFormat);
						boolean force = cbForce.isChecked();
						String postData = PostDataBuilder.scheduleSvcCheck(hostName, serviceName, checkTime, force);
						String res = instance.sendCmd(postData);
						Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 2:
				if(service.currentStatusDetail.contains("acknowledged")){
					alert.setMessage(R.string.removeServiceProblemAcknoledgementRequest);
					posListener = getStdListener(PostDataBuilder.removeSvcAcknowledgement(hostName, serviceName));
				}else if(service.currentStatus.contains("CRITICAL") || 
						service.currentStatus.contains("WARNING") || 
						service.currentStatus.contains("UNKNOWN")){ 
					
					
					alert.setMessage(R.string.acknowledgeServiceProblemRequest);
					
					ll = new LinearLayout(ServiceDetailActivity.this);
					ll.setOrientation(LinearLayout.VERTICAL);
					
					final TextView txtCommentLabel = new TextView(ServiceDetailActivity.this);
					final EditText txtComment = new EditText(ServiceDetailActivity.this);
					final CheckBox cbSticky = new CheckBox(ServiceDetailActivity.this);
					final CheckBox cbSendNotification = new CheckBox(ServiceDetailActivity.this);
					final CheckBox cbPersistentComment = new CheckBox(ServiceDetailActivity.this);
					
					txtCommentLabel.setText(R.string.comment);
					cbSticky.setText(R.string.stickyAcknowledgement);
					cbSticky.setChecked(true);
					cbSendNotification.setText(R.string.sendNotification);
					cbSendNotification.setChecked(true);
					cbPersistentComment.setText(R.string.persistentComment);
					cbPersistentComment.setChecked(false);
					
					ll.addView(txtCommentLabel);
					ll.addView(txtComment);
					ll.addView(cbSticky);
					ll.addView(cbSendNotification);
					ll.addView(cbPersistentComment);
					alert.setView(ll);
					
					posListener = new DialogInterface.OnClickListener() {

						@Override
						public void onClick(DialogInterface dialog, int which) {
							String comment = txtComment.getText().toString();
							String postData = PostDataBuilder.acknowledgeSvcProblem(hostName, serviceName, 
									instance.username, comment, cbSticky.isChecked(), 
									cbSendNotification.isChecked(), cbPersistentComment.isChecked());
							String res = instance.sendCmd(postData);
							Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
						}
							
					};
					
					
				}else{
					alert.setMessage(R.string.noProblemToAck);
					posListener = new DialogInterface.OnClickListener() {

						@Override
						public void onClick(DialogInterface dialog, int which) {
							// nothing to implement
						}
							
					};
					
				}
				break;
			case 3:
				alert.setMessage(R.string.scheduleServiceDowntimeRequest);
				
				
				ScrollView sv = new ScrollView(ServiceDetailActivity.this);
				ll = new LinearLayout(ServiceDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtCommentLabel = new TextView(ServiceDetailActivity.this);
				final EditText txtComment = new EditText(ServiceDetailActivity.this);
				final TextView txtStartTimeLabel = new TextView(ServiceDetailActivity.this);
				final DateTimePicker dtpStartTime = new DateTimePicker(ServiceDetailActivity.this);
				final TextView txtEndTimeLabel = new TextView(ServiceDetailActivity.this);
				final DateTimePicker dtpEndTime = new DateTimePicker(ServiceDetailActivity.this);
				
				final Spinner spType = new Spinner(ServiceDetailActivity.this);
				
				final TextView txtHoursLabel = new TextView(ServiceDetailActivity.this);
				final EditText txtHours = new EditText(ServiceDetailActivity.this);
				final TextView txtMinutesLabel = new TextView(ServiceDetailActivity.this);
				final EditText txtMinutes = new EditText(ServiceDetailActivity.this);
				
				
				txtCommentLabel.setText(R.string.comment);
				txtStartTimeLabel.setText(R.string.startTime);
				txtEndTimeLabel.setText(R.string.endTime);
				
				spType.setAdapter(ArrayAdapter.createFromResource(ServiceDetailActivity.this, R.array.downtimeTypes, android.R.layout.simple_spinner_item));
				spType.setSelection(1);
				txtHoursLabel.setText(R.string.ifFlexibleHours);
				txtMinutesLabel.setText(R.string.ifFlexibleMinutes);
				
				
				ll.addView(txtCommentLabel);
				ll.addView(txtComment);
				ll.addView(txtStartTimeLabel);
				ll.addView(dtpStartTime);
				ll.addView(txtEndTimeLabel);
				ll.addView(dtpEndTime);
				ll.addView(spType);
				ll.addView(txtHoursLabel);
				ll.addView(txtHours);
				ll.addView(txtMinutesLabel);
				ll.addView(txtMinutes);
				
				sv.addView(ll);
				alert.setView(sv);
				
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String comment = txtComment.getText().toString();
						String startTime = dtpStartTime.getDateString(instance.dateFormat);
						String endTime = dtpEndTime.getDateString(instance.dateFormat);
						int type = spType.getSelectedItemPosition();
						String hours = txtHours.getText().toString();
						String minutes = txtMinutes.getText().toString();
						String postData = PostDataBuilder.scheduleSvcDowntime(hostName, serviceName, 
								instance.username, comment, 
								startTime, endTime, type, hours, minutes);
						String res = instance.sendCmd(postData);
						Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 4:
				alert.setMessage(R.string.addServiceCommentRequest);
				
				ll = new LinearLayout(ServiceDetailActivity.this);
				ll.setOrientation(LinearLayout.VERTICAL);
				
				final TextView txtHostCommentLabel = new TextView(ServiceDetailActivity.this);
				final EditText txtHostComment = new EditText(ServiceDetailActivity.this);
				final CheckBox cbPersistent = new CheckBox(ServiceDetailActivity.this);
				
				txtHostCommentLabel.setText(R.string.comment);
				cbPersistent.setText(R.string.persistent);
				cbPersistent.setChecked(true);
				
				ll.addView(txtHostCommentLabel);
				ll.addView(txtHostComment);
				ll.addView(cbPersistent);
				alert.setView(ll);
				
				posListener = new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface dialog, int which) {
						String comment = txtHostComment.getText().toString();
						String postData = PostDataBuilder.addSvcComment(hostName, serviceName, instance.username, comment, cbPersistent.isChecked());
						String res = instance.sendCmd(postData);
						Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
					}
						
				};
				break;
			case 5:
				alert.setMessage(R.string.deleteAllServiceCommentsRequest);
				posListener = getStdListener(PostDataBuilder.delAllSvcComments(hostName, serviceName));
				break;
			}
			
			negListener = new DialogInterface.OnClickListener() {
				  public void onClick(DialogInterface dialog, int whichButton) {
				    // nothing to implement
				  }
			};
			
			alert.setPositiveButton(R.string.ok, posListener);
			alert.setNegativeButton(R.string.cancel, negListener);
			alert.show();
			
		}
		
	}

	private class ServiceDetailAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private int size;
		private Service service;
		
		public ServiceDetailAdapter(){
			currentModel = instance.model;
			
			int hostPos = currentModel.getHostPosition(hostName);
			
			if(hostPos < 0){
				size = 0;
				return;
			}
			
			Host host = currentModel.hosts.get(hostPos);  
			
			int servicePos = host.getServicePosition(serviceName);
			
			if(servicePos < 0){
				size = 0;
			}else{
				size = 19;
				service = host.hostServices.get(servicePos);
			}
			
			
		}
		
		@Override
		public int getCount() {
			return size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			LinearLayout ll = new LinearLayout(ServiceDetailActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			TextView txtHeader = new TextView(ServiceDetailActivity.this);
			txtHeader.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			TextView txtData = new TextView(ServiceDetailActivity.this);
			
			
			switch(position){
			case 0:
				txtHeader.setText(R.string.serviceStatus);
				txtData.setText(service.currentStatusDetail);
				break;
			case 1:
				txtHeader.setText(R.string.statusInformation);
				txtData.setText(service.statusInformation);
				break;
			case 2:
				txtHeader.setText(R.string.performanceData);
				txtData.setText(service.performanceData);
				break;
			case 3:
				txtHeader.setText(R.string.currentAttempt);
				txtData.setText(service.currentAttempt);
				break;
			case 4:
				txtHeader.setText(R.string.lastCheckTime);
				txtData.setText(service.lastCheckTime);
				break;
			case 5:
				txtHeader.setText(R.string.checkType);
				txtData.setText(service.checkType);
				break;
			case 6:
				txtHeader.setText(R.string.checkLatency);
				txtData.setText(service.checkLatencyDuration);
				break;
			case 7:
				txtHeader.setText(R.string.nextScheduledActiveCheck);
				txtData.setText(service.nextScheduledCheck);
				break;
			case 8:
				txtHeader.setText(R.string.lastStateChange);
				txtData.setText(service.lastStateChange);
				break;
			case 9:
				txtHeader.setText(R.string.lastNotification);
				txtData.setText(service.lastNotification);
				break;
			case 10:
				txtHeader.setText(R.string.isThisServiceFlapping);
				txtData.setText(service.isThisServiceFlapping);
				break;
			case 11:
				txtHeader.setText(R.string.inScheduledDowntime);
				txtData.setText(service.inScheduledDowntime);
				break;
			case 12:
				txtHeader.setText(R.string.lastUpdate);
				txtData.setText(service.lastUpdate);
				break;
			case 13:
				txtHeader.setText(R.string.activeChecks);
				txtData.setText(service.activeChecks);
				break;
			case 14:
				txtHeader.setText(R.string.passiveChecks);
				txtData.setText(service.passiveChecks);
				break;
			case 15:
				txtHeader.setText(R.string.obsessing);
				txtData.setText(service.obsessing);
				break;
			case 16:
				txtHeader.setText(R.string.notifications);
				txtData.setText(service.notifications);
				break;
			case 17:
				txtHeader.setText(R.string.eventHandler);
				txtData.setText(service.eventHandler);
				break;
			case 18:
				txtHeader.setText(R.string.flapDetection);
				txtData.setText(service.flapDetection);
				break;
			}
			
			ll.addView(txtHeader);
			ll.addView(txtData);
			return ll;
		}
		
	}
	
	
	
	private String hostName, serviceName;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_cmd_layout);
		
		Bundle extras = getIntent().getExtras();
		hostName = extras.getString("HOSTNAME"); 
		serviceName = extras.getString("SERVICENAME");
		Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));
		Service service = host.hostServices.get(host.getServicePosition(serviceName));
		
		if(!extras.getBoolean("POLLED", false) && 
				service.currentStatusDetail.equals("")){
			poll(); 
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_SERVICEDETAIL + hostName.replace(" ", "+") + "&service=" + serviceName.replace(" ", "+"));
	}

	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.SERVICEDETAIL)return;
		
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new ServiceDetailAdapter());
		
		list.setOnItemClickListener(getModelListItemListener());
		
		processManagementBar();
		
	}
	
	
	private AdapterView.OnItemClickListener getModelListItemListener(){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				Host host = instance.model.hosts.get(instance.model.getHostPosition(hostName));  
				Service service = host.hostServices.get(host.getServicePosition(serviceName));
				String res = "";
				
				switch(pos){
				case 13:
					if(service.activeChecks.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableSvcCheck(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableSvcCheck(hostName, serviceName));
					}
					break;
				case 14:
					if(service.passiveChecks.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disablePassiveSvcChecks(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enablePassiveSvcChecks(hostName, serviceName));
					}
					break;
				case 15:
					if(service.obsessing.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.stopObsessingOverService(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.startObsessingOverService(hostName, serviceName));
					}
					break;
				case 16:
					if(service.notifications.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableSvcNotifications(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableSvcNotifications(hostName, serviceName));
					}
					break;
				case 17:
					if(service.eventHandler.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableSvcEventHandler(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableSvcEventHandler(hostName, serviceName));
					}
					break;
				case 18:
					if(service.flapDetection.contains("ENABLED")){
						res = instance.sendCmd(PostDataBuilder.disableSvcFlapDetection(hostName, serviceName));
					}else{
						res = instance.sendCmd(PostDataBuilder.enableSvcFlapDetection(hostName, serviceName));
					}
					break;
				}
				if(!res.equals("")){
					Toast.makeText(ServiceDetailActivity.this, res, Toast.LENGTH_SHORT).show();
				}
				
			}
			
		};
	}
	
	
	private void processManagementBar(){ 
		
		final Spinner spinner = ((Spinner)findViewById(R.id.spinnerCmds));
		spinner.setAdapter(new ServiceCommandsAdapter());
		spinner.setSelection(0);
		
		Button btnGo = ((Button)findViewById(R.id.btnStartCmdDialog));
		btnGo.setOnClickListener(new StartCmdBtnListener(spinner)); 
		
	}
	
	
}
