package at.jku.koppensteiner.androgios;


import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.ServiceGroup;

public class ServiceGroupsActivity extends AbstractModelActivity{

	private class ServiceGroupsAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private int size;
		
		public ServiceGroupsAdapter(){
			currentModel = instance.model;
			size = instance.model.serviceGroups.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtGroupName = new TextView(ServiceGroupsActivity.this);
			txtGroupName.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
			
			
			if(size==0){
				txtGroupName.setText(R.string.nothingToDisplay);
				return txtGroupName;
			}
			
			
			ServiceGroup sg = currentModel.serviceGroups.get(position);
			LinearLayout ll = new LinearLayout(ServiceGroupsActivity.this);
			ll.setOrientation(LinearLayout.VERTICAL);
			
			txtGroupName.setText(instance.model.serviceGroups.get(position).serviceGroupName);
			ll.addView(txtGroupName);
			
			TextView txtData = new TextView(ServiceGroupsActivity.this);
			
			txtData.setText(getString(R.string.hostsHeader));
			ll.addView(txtData);
			
			if(!sg.hostStatusSummary.hostsUp.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.hostStatusSummary.hostsUp);
				txtData.setTextColor(Color.GREEN);
				ll.addView(txtData);
			}
			if(!sg.hostStatusSummary.hostsDown.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.hostStatusSummary.hostsDown);
				txtData.setTextColor(Color.RED);
				ll.addView(txtData);
			}
			if(!sg.hostStatusSummary.hostsUnreachable.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.hostStatusSummary.hostsUnreachable);
				txtData.setTextColor(Color.RED);
				ll.addView(txtData);
			}
			if(!sg.hostStatusSummary.hostsPending.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.hostStatusSummary.hostsPending);
				ll.addView(txtData);
			}
			
			txtData = new TextView(ServiceGroupsActivity.this);
			txtData.setText( getString(R.string.servicesHeader));
			ll.addView(txtData); // OK, warning, critical, unknown, pending
			if(!sg.serviceStatusSummary.servicesOk.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.serviceStatusSummary.servicesOk);
				txtData.setTextColor(Color.GREEN);
				ll.addView(txtData);
			}
			if(!sg.serviceStatusSummary.servicesWarning.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.serviceStatusSummary.servicesWarning);
				txtData.setTextColor(Color.YELLOW);
				ll.addView(txtData);
			}
			if(!sg.serviceStatusSummary.servicesCritical.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.serviceStatusSummary.servicesCritical);
				txtData.setTextColor(Color.RED);
				ll.addView(txtData);
			}
			if(!sg.serviceStatusSummary.servicesUnknown.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.serviceStatusSummary.servicesUnknown);
				txtData.setTextColor(Color.RED);
				ll.addView(txtData);
			}
			if(!sg.serviceStatusSummary.servicesPending.equals("")){
				txtData = new TextView(ServiceGroupsActivity.this);
				txtData.setText(sg.serviceStatusSummary.servicesPending);
				ll.addView(txtData);
			}
			
			
			
			return ll;
		}
		
	}
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
			
		
	}

	@Override
	protected void poll(){
		super.poll();
		instance.poll(NagiosInstance.URL_SERVICEGROUPS);
	}

	@Override
	protected void update() {
		super.update();
		
		if(instance.model.lastParsed != MonitoringModel.SERVICEGROUPS)return;
		
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(new ServiceGroupsAdapter());
	}
}
