package at.jku.koppensteiner.androgios;

import java.util.HashMap;
import java.util.Map;

import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Service;

public class ServiceListActivity extends AbstractModelActivity{
	
	private class ServiceListAdapter extends BaseAdapter{

		private MonitoringModel currentModel;
		private Map<Integer, Integer> hostMap;
		private Map<Integer, Integer> srvMap;
		private int size;
		
		public ServiceListAdapter(){
			currentModel = instance.model;
			int hostNr = 0;
			int pos = 0; 
			hostMap = new HashMap<Integer, Integer>();
			srvMap = new HashMap<Integer, Integer>();
			for(Host h : currentModel.hosts){
				hostMap.put(pos, hostNr);
				int srvNr = -1;
				for(@SuppressWarnings("unused") Service s : h.hostServices){
					pos++;
					srvNr++;
					hostMap.put(pos, hostNr);
					srvMap.put(pos, srvNr);
				}
				
				pos++;
				hostNr++;
			}
			size = hostMap.size();
		}
		
		@Override
		public int getCount() {
			return size==0?1:size;
		}

		@Override
		public Object getItem(int position) {
			return position;
		}

		@Override
		public long getItemId(int position) {
			return getItem(position).hashCode();
		}

		@Override
		public View getView(int position, View convertView, ViewGroup parent) {
			
			TextView txtStatus = new TextView(ServiceListActivity.this);
			
			if(size==0){
				txtStatus.setText(R.string.nothingToDisplay);
				txtStatus.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
				return txtStatus;
			}
			
			int hostNr = hostMap.get(position);
			Host host = currentModel.hosts.get(hostNr);
			
			LinearLayout ll = new LinearLayout(ServiceListActivity.this);
			
			if(!srvMap.containsKey(position)){
				txtStatus.setText(getString(R.string.servicesAt) + host.hostName);
				txtStatus.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);
				ll.addView(txtStatus);
			}else{
				int srvNr = srvMap.get(position);
				String status = host.hostServices.get(srvNr).serviceName + " - " + host.hostServices.get(srvMap.get(position)).currentStatus;
				txtStatus.setText(status);
				if(status.contains("OK")){
					txtStatus.setTextColor(Color.GREEN);
				}else if(status.contains("WARNING")){
					txtStatus.setTextColor(Color.YELLOW);
				}else{
					txtStatus.setTextColor(Color.RED);
				}
				txtStatus.setTextSize(TypedValue.COMPLEX_UNIT_PT, 10);	
				ll.addView(txtStatus);
			}
			
			
			return ll;
			
		}
		
	}
	
	private boolean filtered;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.abstract_model_layout);
		
		filtered = getIntent().getBooleanExtra("FILTERED", false);
		
		Bundle extras = getIntent().getExtras();
		if(extras==null || !extras.getBoolean("POLLED", false)){
			poll();
			getIntent().putExtra("POLLED", true);
		}else{
			update();
		}
		
	}
	
	@Override
	protected void poll(){
		super.poll();
		if(filtered){
			Bundle extras = getIntent().getExtras();
			int statusTypeParam = extras.getInt("SERVICESTATUSTYPES");
			int propsParam = extras.getInt("SERVICEPROPS");
			
			instance.poll(NagiosInstance.URL_SERVICELIST + "&servicestatustypes=" + statusTypeParam + "&serviceprops=" + propsParam);
		}else{
			instance.poll(NagiosInstance.URL_SERVICELIST);
		}
	}

	@Override
	protected void update() {
		super.update();
		
		if((filtered && instance.model.lastParsed != MonitoringModel.SERVICELISTFILTERED || 
				!filtered && instance.model.lastParsed != MonitoringModel.SERVICELIST) && 
				instance.model.lastParsed != MonitoringModel.SERVICEDETAIL)return; 
		
		
		final ServiceListAdapter adapter = new ServiceListAdapter();
		ListView list = (ListView) findViewById(R.id.listViewModel);
		list.setAdapter(adapter);
		list.setOnItemClickListener(getListItemListener(adapter));
		
	}
	
	
	
	private AdapterView.OnItemClickListener getListItemListener(final ServiceListAdapter adapter){
		return new AdapterView.OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int pos,
					long id) {
				
				if(adapter.size==0||!adapter.srvMap.containsKey(pos))return;
				
				int hostNr = adapter.hostMap.get(pos);
				int srvNr = adapter.srvMap.get(pos);
				Host host = adapter.currentModel.hosts.get(hostNr);
				if(host.hostServices.get(srvNr).currentStatus.contains("PENDING"))return;
				String hostName = host.hostName;
				String serviceName = host.hostServices.get(srvNr).serviceName; 
				Intent intent = new Intent();
				intent.putExtra("HOSTNAME", hostName);
				intent.putExtra("SERVICENAME", serviceName);
				intent.setClass(MasterController.getInstance().getAppCtx(), ServiceDetailActivity.class);
				startActivity(intent);
			}
		};
	}
	
}
