package at.jku.koppensteiner.androgios.nagios;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;


import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.service.PollingService;
import at.jku.koppensteiner.androgios.util.SSLHelper;

public class MasterController extends Application{

	public boolean vibrateOnAlarm;
	public boolean soundOnAlarm;
	public boolean alarmOnUpdateFailed;
	public boolean useMobileNetwork;
	
	private static MasterController mc = null;
	private List<NagiosInstance> nagiosInstances;
	private Context appCtx;
	private Intent pollingServiceIntent;
	
	private boolean pollFreeIntervalEnabled;
	private Calendar pollFreeStart;
	private Calendar pollFreeEnd;
	
	private boolean alarmFreeIntervalEnabled;
	private Calendar alarmFreeStart;
	private Calendar alarmFreeEnd;
	
	private MasterController(){
		nagiosInstances = new ArrayList<NagiosInstance>();
		
//		pollFreeIntervalEnabled = false;
//		pollFreeStart = null;
//		pollFreeEnd = null;
//		
//		alarmFreeIntervalEnabled = false;
//		alarmFreeStart = null;
//		alarmFreeEnd = null;
//		
//		vibrateOnAlarm = false;
//		soundOnAlarm = true;
	}
	
	
	public static MasterController getInstance(){
		
		if(mc==null){
			mc = new MasterController();
		}
		return mc;
	}
	
	public NagiosInstance getActiveNagiosInstance(){
		if(nagiosInstances.size()==0)return null;
		return nagiosInstances.get(0);
	}
	
	public void setAppCtx(Context appCtx){
		this.appCtx = appCtx;
		readConfig();
	}
	
	public Context getAppCtx(){
		return appCtx;
	}
	
	public void enableService(){
		pollingServiceIntent = new Intent(appCtx, PollingService.class);
		appCtx.startService(pollingServiceIntent);
		
	}
	
	public void disableService(){
		appCtx.stopService(pollingServiceIntent);
		pollingServiceIntent = null;
		
	}
	
	public void restartService(){
		disableService();
		enableService();
	}
	
	
	public void showError(String msg){
		Toast.makeText(appCtx, msg, Toast.LENGTH_LONG).show();
	}
	
	public void setPollFreeIntervalEnabled(boolean b){
		pollFreeIntervalEnabled = b;
		if(pollingServiceIntent!=null)restartService();
	}
	
	public void setPollFreeIntervalStart(String startTime){
		pollFreeStart = parseTime(startTime);
		if(pollingServiceIntent!=null)restartService();
	}
	
	public void setPollFreeIntervalEnd(String endTime){
		pollFreeEnd = parseTime(endTime);
		if(pollingServiceIntent!=null)restartService();
	}
	
	public Calendar getPollFreeIntervallEnd(){
		return pollFreeEnd;
	}
	
	public boolean withinPollFreeInterval(Calendar d){
		return pollFreeIntervalEnabled && checkWithinInterval(d, pollFreeStart, pollFreeEnd);
	}
	
	
	public void setAlarmFreeIntervalEnabled(boolean b){
		alarmFreeIntervalEnabled = b;
	}
	
	public void setAlarmFreeIntervalStart(String startTime){
		alarmFreeStart = parseTime(startTime);
	}
	
	public void setAlarmFreeIntervalEnd(String endTime){
		alarmFreeEnd = parseTime(endTime);
	}
	
	public boolean withinAlarmFreeInterval(Calendar d){
		return alarmFreeIntervalEnabled && checkWithinInterval(d, alarmFreeStart, alarmFreeEnd);
	}
	
	private boolean checkWithinInterval(Calendar d, Calendar from, Calendar to){
		
		if(from==null||to==null)return false;
		
		
		int fromMins = from.get(Calendar.HOUR_OF_DAY)*60 + from.get(Calendar.MINUTE);
		int toMins = to.get(Calendar.HOUR_OF_DAY)*60 + to.get(Calendar.MINUTE);
		int dMins = d.get(Calendar.HOUR_OF_DAY)*60 + d.get(Calendar.MINUTE);
		
		if(fromMins<toMins){
			return fromMins<=dMins && dMins<=toMins;
		}else if(fromMins>toMins){
			return !(toMins<=dMins && dMins<=fromMins);
		}
		
		return true;
		
	}
	
	
	private Calendar parseTime(String time){
		if(time.length()!=5)return null;
		Calendar cal = GregorianCalendar.getInstance();
		try{
			int hour = Integer.parseInt(time.substring(0, 2));
			int minute = Integer.parseInt(time.substring(3, 5));
			if(0<=hour&&hour<24&&0<=minute&&minute<60){
				cal.set(Calendar.HOUR_OF_DAY, hour); 
				cal.set(Calendar.MINUTE, minute);
			}else{
				cal=null;
			}
		}catch(NumberFormatException e){
			cal = null;
		}
		return cal;
	}
	
	

	private void readConfig(){
		
		
		String url;
		String username;
		String password;
		
		SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(appCtx);
		
		try{
			url = sp.getString("configuration_nagios_url", "http://localhost/cgi-bin/nagios3");
			username = sp.getString("configuration_nagios_username", "nagiosadmin");
			password = sp.getString("configuration_nagios_password", "password");
		}catch(Exception e){
			url = "http://localhost/cgi-bin/nagios3";
			username = "nagiosadmin";
			password = "password";
		}
		
		NagiosInstance instance = new NagiosInstance(url, username, password);
		nagiosInstances.add(instance);
		
		instance.acceptSelfSignedCert = sp.getBoolean("configuration_acc_self_cert", false);
		if(instance.acceptSelfSignedCert){
			SSLHelper.trustAllHosts();
		}else{
			SSLHelper.trustDefaultHosts();
		}
		instance.pollIntervall = Integer.parseInt(sp.getString("configuration_poll_interval", "300"));
		instance.dateFormat = sp.getString("configuration_date_format", "iso8601");
		
		
		soundOnAlarm = sp.getBoolean("configuration_play_sound", true);
		vibrateOnAlarm = sp.getBoolean("configuration_vibration", false);
		alarmOnUpdateFailed = sp.getBoolean("configuration_alarm_on_update_failed", true);
		useMobileNetwork = sp.getBoolean("configuration_use_mobile_network", false);
		
		setPollFreeIntervalEnabled(sp.getBoolean("configuration_enable_poll_free_interval", false));
		setPollFreeIntervalStart(sp.getString("configuration_poll_free_start","00:00"));
		setPollFreeIntervalEnd(sp.getString("configuration_poll_free_end","06:00"));
		
		setAlarmFreeIntervalEnabled(sp.getBoolean("configuration_enable_alarm_free_interval", false));
		setAlarmFreeIntervalStart(sp.getString("configuration_alarm_free_start","00:00"));
		setAlarmFreeIntervalEnd(sp.getString("configuration_alarm_free_end","06:00"));
		
	}
	
}
