package at.jku.koppensteiner.androgios.nagios;


import javax.net.ssl.SSLException;

import at.jku.koppensteiner.androgios.parser.ParserException;

import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Handler;
import android.widget.Toast;
import at.jku.koppensteiner.androgios.AbstractModelActivity;
import at.jku.koppensteiner.androgios.AndrogiosActivity;
import at.jku.koppensteiner.androgios.R;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.TacticalOverview;
import at.jku.koppensteiner.androgios.net.Fetcher;
import at.jku.koppensteiner.androgios.net.CmdSender;
import at.jku.koppensteiner.androgios.net.HttpFetcher;
import at.jku.koppensteiner.androgios.net.HttpsFetcher;
import at.jku.koppensteiner.androgios.parser.CommentsParser;
import at.jku.koppensteiner.androgios.parser.DowntimesParser;
import at.jku.koppensteiner.androgios.parser.HostDetailParser;
import at.jku.koppensteiner.androgios.parser.HostGroupsParser;
import at.jku.koppensteiner.androgios.parser.HostListParser;
import at.jku.koppensteiner.androgios.parser.OutagesParser;
import at.jku.koppensteiner.androgios.parser.Parser;
import at.jku.koppensteiner.androgios.parser.ProcessDetailParser;
import at.jku.koppensteiner.androgios.parser.ServiceDetailParser;
import at.jku.koppensteiner.androgios.parser.ServiceGroupsParser;
import at.jku.koppensteiner.androgios.parser.ServiceListParser;
import at.jku.koppensteiner.androgios.parser.TACParser;


public class NagiosInstance {

	public class Poller{

		private Fetcher fetcher;
		
		public void pollTacticalOverview(){
			
			new Thread(){
				
				private void sendBC(){
					
					final Intent widgetBC = new Intent("android.appwidget.action.APPWIDGET_UPDATE");
					final Intent activityBC = new Intent(AndrogiosActivity.ACTION_TAC_UPDATE);
					MasterController.getInstance().getAppCtx().sendBroadcast(widgetBC);
					MasterController.getInstance().getAppCtx().sendBroadcast(activityBC);
				}
				
				@Override
				public void run(){
					if(!checkConnectivity()){
						tacticalOverview.updateSuccessful = false;
						sendBC();
						return;
					}
					
					if(secureConnection()){
						fetcher = new HttpsFetcher(baseUrl + "/tac.cgi", 
								username, password, acceptSelfSignedCert);
					}else{
						fetcher = new HttpFetcher(baseUrl + "/tac.cgi", 
								username, password);
					}
					
					synchronized(tacticalOverview){
						
						String html = "";
						try {
							html = fetcher.fetchHTML();
							TACParser tp = new TACParser(html, NagiosInstance.this);
							tp.parse();
						} catch (SSLException e) {
							tacticalOverview.updateSuccessful = false;
			        		tacticalOverview.errorCause = TacticalOverview.ERRORCAUSE_SSL;
						}catch (ParserException e) {
			        		tacticalOverview.updateSuccessful = false;
			        		tacticalOverview.errorCause = TacticalOverview.ERRORCAUSE_PARSING;
			        	}
			        	
			        	sendBC();
			        	
			        }
				}
			}.start();
			
		}
		
		
		public void poll(final String extUrl){
			
			new Thread(){
				
				private void sendBC(){
					final Intent activityBC = new Intent(AbstractModelActivity.ACTION_MODEL_UPDATE);
					MasterController.getInstance().getAppCtx().sendBroadcast(activityBC);
				}
				
				@Override
				public void run(){
					
					if(!checkConnectivity()){
						model.updateSuccessful = false;
						sendBC();
						return;
					}
					
					if(secureConnection()){
						fetcher = new HttpsFetcher(baseUrl + "/" + extUrl, 
								username, password, acceptSelfSignedCert);
					}else{
						fetcher = new HttpFetcher(baseUrl + "/" + extUrl, 
								username, password);
					}
					

					synchronized(model){
						
						String html = "";
						try {
							html = fetcher.fetchHTML();
							
							Parser parser;
							if(extUrl.equals(URL_HOSTPROBLEMS)){
								parser = new HostListParser(html, NagiosInstance.this, true, false);
							}else if(extUrl.equals(URL_HOSTLIST)){
								parser = new HostListParser(html, NagiosInstance.this, false, false);
							}else if(extUrl.startsWith(URL_HOSTLIST)){
								parser = new HostListParser(html, NagiosInstance.this, false, true);
							}else if(extUrl.equals(URL_HOSTGROUPS)){
								parser = new HostGroupsParser(html, NagiosInstance.this);
							}else if(extUrl.startsWith(URL_HOSTDETAIL)){
								parser = new HostDetailParser(html, NagiosInstance.this, extUrl.substring(URL_HOSTDETAIL.length()).replace("+", " "));
							}else if(extUrl.equals(URL_SERVICEPROBLEMS)){
								parser = new ServiceListParser(html, NagiosInstance.this, true, false);
							}else if(extUrl.equals(URL_SERVICELIST)){
								parser = new ServiceListParser(html, NagiosInstance.this, false, false);
							}else if(extUrl.startsWith(URL_SERVICELIST)){
								parser = new ServiceListParser(html, NagiosInstance.this, false, true);
							}else if(extUrl.equals(URL_SERVICEGROUPS)){
								parser = new ServiceGroupsParser(html, NagiosInstance.this);
							}else if(extUrl.startsWith(URL_SERVICEDETAIL)){
								int start = URL_SERVICEDETAIL.length();
								int end = extUrl.indexOf("&", start);
								String hostName = extUrl.substring(start, end).replace("+", " ");
								start = end+1+"service=".length();
								String serviceName = extUrl.substring(start).replace("+", " ");
								parser = new ServiceDetailParser(html, NagiosInstance.this, hostName,serviceName); 
							}else if(extUrl.equals(URL_OUTAGES)){
								parser = new OutagesParser(html, NagiosInstance.this);
							}else if(extUrl.equals(URL_COMMENTS)){
								parser = new CommentsParser(html, NagiosInstance.this);
							}else if(extUrl.equals(URL_DOWNTIMES)){
								parser = new DowntimesParser(html, NagiosInstance.this);
							}else if(extUrl.equals(URL_NAGIOSPROCESS)){
								parser = new ProcessDetailParser(html, NagiosInstance.this);
							}else{
								assert(false);
								return;
							}
							
							parser.parse();
							
						} catch (SSLException e) {
							model.updateSuccessful = false;
			        		model.errorCause = MonitoringModel.ERRORCAUSE_SSL;
						}catch (ParserException e) {
			        		model.updateSuccessful = false;
			        		model.errorCause = MonitoringModel.ERRORCAUSE_PARSING;
			        	}
			        	
			        	sendBC();
			        	
			        }
					
					
				}
			}.start();
			
		}
		
	}

	
	public static final String URL_HOSTLIST = "status.cgi?hostgroup=all&style=hostdetail";
	public static final String URL_HOSTGROUPS = "status.cgi?hostgroup=all&style=summary";
	public static final String URL_HOSTDETAIL = "extinfo.cgi?type=1&host=";
	public static final String URL_HOSTPROBLEMS = "status.cgi?hostgroup=all&style=hostdetail&hoststatustypes=12";
	public static final String URL_SERVICELIST = "status.cgi?host=all";
	public static final String URL_SERVICEGROUPS = "status.cgi?servicegroup=all&style=summary";
	public static final String URL_SERVICEDETAIL = "extinfo.cgi?type=2&host=";
	public static final String URL_SERVICEPROBLEMS = "status.cgi?host=all&servicestatustypes=28";
	public static final String URL_OUTAGES = "outages.cgi";
	public static final String URL_COMMENTS = "extinfo.cgi?&type=3";
	public static final String URL_DOWNTIMES = "extinfo.cgi?&type=6";
	public static final String URL_NAGIOSPROCESS = "extinfo.cgi?&type=0";
	public static final String URL_COMMANDS = "cmd.cgi";
	

	public String baseUrl;
	public String username;
	protected String password;
	public int pollIntervall; // in seconds
	public boolean acceptSelfSignedCert;
	public String dateFormat;
	
	public MonitoringModel model;
	public TacticalOverview tacticalOverview;
	private final Poller poller;
	
	public NagiosInstance(String baseUrl, String username, String password){
		this.baseUrl = baseUrl;
		this.username = username;
		this.password = password;
		
		model = new MonitoringModel();
		tacticalOverview = new TacticalOverview();
		poller = new Poller();
		
	}
	
	
	public void pollTacticalOverview(){
		poller.pollTacticalOverview();
	}
	
	public void poll(String extUrl){
		poller.poll(extUrl);
	}
	
	
	public String sendCmd(final String postData){
		
		if(!checkConnectivity())return "No Network Connection";
		
		new Thread(){
			Handler handler = new Handler();
			@Override
			public void run(){
				final String res = new CmdSender(baseUrl+"/"+URL_COMMANDS, username, password, acceptSelfSignedCert).send(postData);
				handler.post(new Runnable(){

					@Override
					public void run() {
						Toast.makeText(MasterController.getInstance().getAppCtx(), res, Toast.LENGTH_LONG).show();
					}});
				
			}
			
		}.start();
		
		return MasterController.getInstance().getAppCtx().getString(R.string.sendingCommand);//"sending Command...";
	}
	
	
	public boolean secureConnection(){
		return baseUrl.contains("https://");
	}
	

	
	public void setPassword(String password){
		this.password = password;
	}
	
	
	private boolean checkConnectivity(){
		ConnectivityManager cm = (ConnectivityManager) MasterController.getInstance().getAppCtx().getSystemService(Context.CONNECTIVITY_SERVICE);
		NetworkInfo info = cm.getActiveNetworkInfo();
		
		if(MasterController.getInstance().useMobileNetwork){
			return info!=null && info.isConnected();
		}else{
			return info!=null && info.isConnected() && info.getType() != ConnectivityManager.TYPE_MOBILE;
		}
		
	}
	
}
