package at.jku.koppensteiner.androgios.nagios.model;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

public class MonitoringModel {
	
	public static final int ERRORCAUSE_SSL = 1;
	public static final int ERRORCAUSE_PARSING = 2;
	
	public static final int HOSTDETAIL = 0x1;
	public static final int HOSTLIST = 0x2;
	public static final int HOSTGROUPS = 0x4;
	public static final int SERVICEDETAIL = 0x8;
	public static final int SERVICELIST = 0x10;
	public static final int SERVICEGROUPS = 0x20;
	public static final int OUTAGES = 0x40;
	public static final int DOWNTIMES = 0x80;
	public static final int COMMENTS = 0x100;
	public static final int NAGIOSPROCESS = 0x200;
	public static final int HOSTPROBLEMS = 0x400;
	public static final int SERVICEPROBLEMS = 0x800;
	public static final int HOSTLISTFILTERED = 0x1000;
	public static final int SERVICELISTFILTERED = 0x2000;

	public int lastParsed;
	public boolean updateSuccessful;
	public Date lastUpdate;
	public int errorCause;
	
	public List<HostGroup> hostGroups;
	public List<Host> hosts;
	public List<ServiceGroup> serviceGroups;

	public List<HostDowntime> hostDowntimes;
	public List<ServiceDowntime> serviceDowntimes;
	
	public List<HostComment> hostComments;
	public List<ServiceComment> serviceComments;
	
	public List<Outage> outages;
	
	public Process process;
	
	
	public MonitoringModel(){
		lastUpdate = null;
		init();
	}


	public void reset() {
		init();
	}
	
	private void init(){
		updateSuccessful = false;
		lastUpdate = null;
		lastParsed = 0x0;
		
		hostGroups = new ArrayList<HostGroup>();
		hosts = new ArrayList<Host>();
		serviceGroups = new ArrayList<ServiceGroup>();
		hostDowntimes = new ArrayList<HostDowntime>();
		serviceDowntimes = new ArrayList<ServiceDowntime>();
		hostComments = new ArrayList<HostComment>();
		serviceComments = new ArrayList<ServiceComment>();
		outages = new ArrayList<Outage>();
		process = new Process();
	}
	
	public int getHostPosition(String hostName){
		
		Iterator<Host> it =  hosts.iterator();
		int cnt = 0;
		while(it.hasNext()){
			Host h = it.next();
			if(h.hostName.equals(hostName)) return cnt;
			cnt++;
		}
		
		return -1;
	}
	
	public int getOutagePosition(String hostName){
		
		Iterator<Outage> it =  outages.iterator();
		int cnt = 0;
		while(it.hasNext()){
			Outage o = it.next();
			if(o.host.equals(hostName)) return cnt;
			cnt++;
		}
		
		return -1;
	}
	
	public int getHostCommentPosition(String commentID){
		Iterator<HostComment> it =  hostComments.iterator();
		int cnt = 0;
		while(it.hasNext()){
			HostComment c = it.next();
			if(c.commentId.equals(commentID)) return cnt;
			cnt++;
		}
		return -1;
	}
	
	public int getServiceCommentPosition(String commentId){
		Iterator<ServiceComment> it =  serviceComments.iterator();
		int cnt = 0;
		while(it.hasNext()){
			ServiceComment c = it.next();
			if(c.commentId.equals(commentId)) return cnt;
			cnt++;
		}
		return -1;
	}


	public int getHostDowntimePosition(String downtimeId) {
		Iterator<HostDowntime> it = hostDowntimes.iterator();
		int cnt = 0;
		while(it.hasNext()){
			HostDowntime hd = it.next(); 
			if(hd.downtimeId.equals(downtimeId))return cnt;
			cnt++;
		}
		return -1;
	}


	public int getServiceDowntimePosition(String downtimeId) {
		Iterator<ServiceDowntime> it = serviceDowntimes.iterator();
		int cnt = 0;
		while(it.hasNext()){
			ServiceDowntime sd = it.next(); 
			if(sd.downtimeId.equals(downtimeId))return cnt;
			cnt++;
		}
		return -1;
	}
	
	@Override
	public Object clone(){
		MonitoringModel clone = new MonitoringModel();
		
		clone.updateSuccessful = new Boolean(updateSuccessful);
		clone.lastParsed = new Integer(lastParsed);
		
		
		for(HostGroup hg : hostGroups){
			clone.hostGroups.add((HostGroup)hg.clone());
		}
		
		for(Host h: hosts){
			clone.hosts.add((Host)h.clone());
		}
		
		for(ServiceGroup sg : serviceGroups){
			clone.serviceGroups.add((ServiceGroup)sg.clone());
		}
		
		for(HostDowntime hdt : hostDowntimes){
			clone.hostDowntimes.add((HostDowntime)hdt.clone());
		}

		for(ServiceDowntime sdt : serviceDowntimes){
			clone.serviceDowntimes.add((ServiceDowntime)sdt.clone());
		}
		
		for(HostComment hc : hostComments){
			clone.hostComments.add((HostComment)hc.clone());
		}

		for(ServiceComment sc : serviceComments){
			clone.serviceComments.add((ServiceComment)sc.clone());
		}
		
		for(Outage o : outages){
			clone.outages.add((Outage)o.clone());
		}
		
		clone.process = (Process)process.clone();
		
		return clone;
	}
	
}
