package at.jku.koppensteiner.androgios.net;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.SocketTimeoutException;
import java.net.URL;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLException;

import at.jku.koppensteiner.androgios.util.SSLHelper;


public class HttpsFetcher implements Fetcher{

	
	private String url;
	private String username;
	private String password;
	private boolean acceptSelfSignedCert;
	
	
	
	public HttpsFetcher(String url, String username, String password, boolean acceptSelfSignedCert){
		this.url = url;
		this.username = username;
		this.password = password;
		this.acceptSelfSignedCert = acceptSelfSignedCert;
		
	}
	
	
	@Override
	public String fetchHTML() throws SSLException {
		
		String html = null;
		int i = 3;
		while(html == null && i>0){
			i--;
			html = tryFetch();
		}
		
		return html;
		
	}
	
	
	private String tryFetch() throws SSLException{
		URL url = null;
		try {
			url = new URL(this.url);
		} catch (MalformedURLException e) {
			return null;
		}

		final HttpsURLConnection c;
		int status = 0;
		

		
		try {
			c = (HttpsURLConnection) url.openConnection();
			if(acceptSelfSignedCert)c.setHostnameVerifier(SSLHelper.ACCEPT_ALL_VERIFIER);
			c.setRequestProperty("Authorization", "Basic "
					+ Base64.encodeString(username + ":" + password));
			c.setConnectTimeout(1000*60);
			c.setReadTimeout(1000*60);
			c.connect();
			status = c.getResponseCode();
		} catch (SocketTimeoutException e) {
			return null;
		} catch(SSLException e){ 
			throw e;
		} catch (IOException e){
			return null;
		}

		if (status != 200)return null;
		
		byte[] b = null;

		try {
			b = readStream(c.getInputStream());
		} catch (IOException e) {
			e.printStackTrace();
		}
		if (c != null)c.disconnect();
		

		String res = new String(b);

		return res;
	}
	
	private byte[] readStream(InputStream is) {
		try {
			ByteArrayOutputStream baos = new ByteArrayOutputStream();

			byte[] buffer = new byte[1024];
			while (true) {
				int len = is.read(buffer);
				if (len == -1) {
					break;
				}
				baos.write(buffer, 0, len);
			}
			return baos.toByteArray();
		} catch (Exception e) {
		}
		return new byte[0];
	}
	


}
