package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import java.util.Iterator;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostDowntime;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.ServiceDowntime;

public class DowntimesParser extends Parser{

	public DowntimesParser(String html, NagiosInstance instance) {
		super(html, instance);
	}

	@Override
	protected void updateModel() {
		
		MonitoringModel model = new MonitoringModel();
		model.lastParsed = MonitoringModel.DOWNTIMES;
		
		
		Document doc = Jsoup.parse(html);
		
		Element hostDowntimesTable = doc.select("table.downtime").get(0);
		Element serviceDowntimesTable = doc.select("table.downtime").get(1);
		
		Elements rows = hostDowntimesTable.select("> * > tr");
		Iterator<Element> it = rows.iterator();
		it.next();
		
		HostDowntime hostDowntime;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td");
			if(rowData.size()==1)continue; //table is empty
			
			hostDowntime = new HostDowntime();
			
			hostDowntime.hostName = rowData.get(0).text();
			hostDowntime.entryTime = rowData.get(1).text();
			hostDowntime.author = rowData.get(2).text();
			hostDowntime.comment = rowData.get(3).text();
			hostDowntime.startTime = rowData.get(4).text();
			hostDowntime.endTime = rowData.get(5).text();
			hostDowntime.type = rowData.get(6).text();
			hostDowntime.duration = rowData.get(7).text();
			hostDowntime.downtimeId = rowData.get(8).text();
			hostDowntime.triggerId = rowData.get(9).text();
			
			model.hostDowntimes.add(hostDowntime);
		}
			
		rows = serviceDowntimesTable.select("> * > tr");
		it = rows.iterator();
		it.next();
		ServiceDowntime serviceDowntime;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td");
			if(rowData.size()==1)continue; //table is empty
			
			serviceDowntime = new ServiceDowntime();
			
			serviceDowntime.hostName = rowData.get(0).text();
			serviceDowntime.serviceName = rowData.get(1).text();
			serviceDowntime.entryTime = rowData.get(2).text();
			serviceDowntime.author = rowData.get(3).text();
			serviceDowntime.comment = rowData.get(4).text();
			serviceDowntime.startTime = rowData.get(5).text();
			serviceDowntime.endTime = rowData.get(6).text();
			serviceDowntime.type = rowData.get(7).text();
			serviceDowntime.duration = rowData.get(8).text();
			serviceDowntime.downtimeId = rowData.get(9).text();
			serviceDowntime.triggerId = rowData.get(10).text();
			
			model.serviceDowntimes.add(serviceDowntime);
		}
		
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
	}

}
