package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;

public class HostDetailParser extends Parser{

	
	private String hostName;
	
	public HostDetailParser(String html, NagiosInstance instance, String hostName) {
		super(html, instance);
		this.hostName = hostName;
	}

	
	@Override
	protected void updateModel(){

		MonitoringModel model = (MonitoringModel) instance.model.clone();
		
		int pos = model.getHostPosition(hostName);
		Host host = model.hosts.get(pos);
		model.lastParsed = MonitoringModel.HOSTDETAIL;
		
		Document doc = Jsoup.parse(html);
		
		Elements vals = doc.select("[class=dataval]");
		
		if(vals.size()==25){//nagios v2
			host.hostStatusDetail = vals.get(0).text() + " (for "+ vals.get(12).text() + ")";
			host.statusInformation = vals.get(1).text();
			host.performanceData = vals.get(2).text();
			host.currentAttempt = vals.get(3).text() + " (" + vals.get(4).text() + ")";
			host.lastCheckTime = vals.get(6).text();
			host.checkType = vals.get(5).text();
			host.checkLatencyDuration = vals.get(9).text() + "/" + vals.get(10).text();
			host.nextScheduledActiveCheck = vals.get(8).text();
			host.lastStateChange = vals.get(11).text();
			host.lastNotification = vals.get(13).text();
			host.isThisHostFlapping = vals.get(15).text() + "(" + vals.get(16).text() + " state change)";
			host.inScheduledDowntime = vals.get(17).text();
			host.lastUpdate = vals.get(18).text();
			
			host.activeChecks = vals.get(19).text();
			host.passiveChecks = vals.get(20).text();
			host.obsessing = vals.get(21).text();
			host.notifications = vals.get(22).text();
			host.eventHandler = vals.get(23).text();
			host.flapDetection = vals.get(24).text();
		}else if(vals.size()== 19){//nagios v3
			
			host.hostStatusDetail = vals.get(0).text();
			host.statusInformation = vals.get(1).text();
			host.performanceData = vals.get(2).text();
			host.currentAttempt = vals.get(3).text();
			host.lastCheckTime = vals.get(4).text();
			host.checkType = vals.get(5).text();
			host.checkLatencyDuration = vals.get(6).text();
			host.nextScheduledActiveCheck = vals.get(7).text();
			host.lastStateChange = vals.get(8).text();
			host.lastNotification = vals.get(9).text();
			host.isThisHostFlapping = vals.get(10).text();
			host.inScheduledDowntime = vals.get(11).text();
			host.lastUpdate = vals.get(12).text();
			
			host.activeChecks = vals.get(13).text();
			host.passiveChecks = vals.get(14).text();
			host.obsessing = vals.get(15).text();
			host.notifications = vals.get(16).text();
			host.eventHandler = vals.get(17).text();
			host.flapDetection = vals.get(18).text();
		}
		
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
		
	}
	
}
