package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import java.util.Iterator;



import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.HostGroup;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;

public class HostGroupsParser extends Parser{

	
	public HostGroupsParser(String html, NagiosInstance instance){
		super(html, instance);
	}
	
	
	@Override
	protected void updateModel(){
		
		MonitoringModel model = new MonitoringModel();
		model.lastParsed = MonitoringModel.HOSTGROUPS;
		
		Document doc = Jsoup.parse(html);
		
		Elements elems = doc.select("TABLE[class=status] > * > tr"); //each table row
		Iterator<Element> it = elems.iterator();
		
		it.next(); //skip headers
		
		HostGroup hg;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td"); // only DIRECT table data descendants of row
			hg = new HostGroup();
			
			hg.hostGroupName = rowData.get(0).text();
			
			//hosts
			
			Element entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusUP").first();
			if(entry != null) hg.hostStatusSummary.hostsUp = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusDOWN").first();
			if(entry != null)hg.hostStatusSummary.hostsDown = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusUNREACHABLE").first();
			if(entry != null)hg.hostStatusSummary.hostsUnreachable = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusPENDING").first();
			if(entry != null)hg.hostStatusSummary.hostsPending = entry.text();
			
			//services
			
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusOK").first();
			if(entry != null)hg.serviceStatusSummary.servicesOk = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusWARNING").first();
			if(entry != null)hg.serviceStatusSummary.servicesWarning = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusCRITICAL").first();
			if(entry != null)hg.serviceStatusSummary.servicesCritical = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusUNKNOWN").first();
			if(entry != null)hg.serviceStatusSummary.servicesUnknown = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusPENDING").first();
			if(entry != null)hg.serviceStatusSummary.servicesPending = entry.text();
			
			model.hostGroups.add(hg);
			
		}
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
	}
	
	
}
