package at.jku.koppensteiner.androgios.parser;


import java.util.Date;
import java.util.Iterator;



import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;;

public class HostListParser extends Parser{

	private boolean filtered;
	private boolean problemsOnly;
	
	public HostListParser(String html, NagiosInstance instance, boolean problemsOnly ,boolean filtered){
		super(html, instance);
		this.problemsOnly = problemsOnly;
		this.filtered = filtered;
	}
	
	
	@Override
	protected void updateModel(){
		
		MonitoringModel model = new MonitoringModel();
		
		if(problemsOnly){
			model.lastParsed = MonitoringModel.HOSTPROBLEMS;
		}else if(filtered){
			model.lastParsed = MonitoringModel.HOSTLISTFILTERED;
		}else{
			model.lastParsed = MonitoringModel.HOSTLIST;
		}
		
		
		Document doc = Jsoup.parse(html);
		Elements elems = doc.select("TABLE[class=status] > * > tr"); //each table row
		Iterator<Element> it = elems.iterator();
		
		it.next(); //skip headers
		Host host = null;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td"); // only DIRECT table data descendants of row
			host = new Host();
			String hostName = rowData.get(0).text();
			host.hostName = hostName.substring(0, hostName.length()-1);//remove &nbsp
			host.hostStatus = rowData.get(1).text();
			model.hosts.add(host);
		}
		
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
	}
	
}
