package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import java.util.Iterator;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Outage;

public class OutagesParser extends Parser{

	public OutagesParser(String html, NagiosInstance instance) {
		super(html, instance);
	}

	@Override
	protected void updateModel(){
		
		MonitoringModel model = new MonitoringModel();
		model.lastParsed = MonitoringModel.OUTAGES;
		
		Document doc = Jsoup.parse(html);
		
		Element outagesTable = doc.select("table.data").get(0);
		
		Elements rows = outagesTable.select("> * > tr");
		Iterator<Element> it = rows.iterator();
		it.next(); //skip headers
		
		Outage outage;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td");
			if(rowData.size()==1)continue; //table is empty
			
			outage = new Outage();
			
			outage.severity = rowData.get(0).text();
			outage.host = rowData.get(1).text();
			outage.state = rowData.get(2).text();
			if(rowData.get(3).text().equals("")){
				outage.notes = rowData.get(3).getElementsByAttribute("alt").attr("alt");
			}else{
				outage.notes = rowData.get(3).text();
			}
			outage.stateDuration = rowData.get(4).text();
			outage.nrHostsAffected = rowData.get(5).text();
			outage.nrServicesAffected = rowData.get(6).text();
			
			model.outages.add(outage);
			
		}
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
	}

}
