package at.jku.koppensteiner.androgios.parser;

import java.util.Date;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Service;

public class ServiceDetailParser extends Parser{

	
	private String hostName;
	private String serviceName;
	
	public ServiceDetailParser(String html, NagiosInstance instance, String hostName, String serviceName){
		super(html, instance);
		this.hostName = hostName;
		this.serviceName = serviceName;
	}

	@Override
	protected void updateModel(){
		
		MonitoringModel model = (MonitoringModel) instance.model.clone();
		
		Host host = model.hosts.get(model.getHostPosition(hostName));
		Service service = host.hostServices.get(host.getServicePosition(serviceName));
		
		
		model.lastParsed = MonitoringModel.SERVICEDETAIL;
		
		// don't reset model!!!
		
		Document doc = Jsoup.parse(html);
		
		Elements vals = doc.select("[class=dataval]"); 
		
		if(vals.size()==25){//nagios v2
			service.currentStatusDetail = vals.get(0).text() + " (for "+ vals.get(12).text() + ")";
			service.statusInformation = vals.get(1).text();
			service.performanceData = vals.get(2).text();
			service.currentAttempt = vals.get(3).text() + " (" + vals.get(4).text() + ")";
			service.lastCheckTime = vals.get(6).text();
			service.checkType = vals.get(5).text();
			service.checkLatencyDuration = vals.get(9).text() + "/" + vals.get(10).text();
			service.nextScheduledCheck = vals.get(8).text();
			service.lastStateChange = vals.get(11).text();
			service.lastNotification = vals.get(13).text();
			service.isThisServiceFlapping = vals.get(15).text() + "(" + vals.get(16).text() + " state change)";
			service.inScheduledDowntime = vals.get(17).text();
			service.lastUpdate = vals.get(18).text();
			
			service.activeChecks = vals.get(19).text();
			service.passiveChecks = vals.get(20).text();
			service.obsessing = vals.get(21).text();
			service.notifications = vals.get(22).text();
			service.eventHandler = vals.get(23).text();
			service.flapDetection = vals.get(24).text();
		}else if(vals.size()==19){//nagios v3
		
			service.currentStatusDetail = vals.get(0).text();
			service.statusInformation = vals.get(1).text();
			service.performanceData = vals.get(2).text();
			service.currentAttempt = vals.get(3).text();
			service.lastCheckTime = vals.get(4).text();
			service.checkType = vals.get(5).text();
			service.checkLatencyDuration = vals.get(6).text();
			service.nextScheduledCheck = vals.get(7).text();
			service.lastStateChange = vals.get(8).text();
			service.lastNotification = vals.get(9).text();
			service.isThisServiceFlapping = vals.get(10).text();
			service.inScheduledDowntime = vals.get(11).text();
			service.lastUpdate = vals.get(12).text();
			
			service.activeChecks = vals.get(13).text();
			service.passiveChecks = vals.get(14).text();
			service.obsessing = vals.get(15).text();
			service.notifications = vals.get(16).text();
			service.eventHandler = vals.get(17).text();
			service.flapDetection = vals.get(18).text();
		}
		
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
		
	}
	
}
