package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import java.util.Iterator;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.ServiceGroup;

public class ServiceGroupsParser extends Parser{

	public ServiceGroupsParser(String html, NagiosInstance instance) {
		super(html, instance);
	}

	@Override
	protected void updateModel(){
		MonitoringModel model = new MonitoringModel();
		model.lastParsed = MonitoringModel.SERVICEGROUPS;
		
		Document doc = Jsoup.parse(html);
		
		Elements elems = doc.select("TABLE[class=status] > * > tr"); //each table row
		Iterator<Element> it = elems.iterator();
		
		it.next(); //skip headers
		
		ServiceGroup sg;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td"); // only DIRECT table data descendants of row
			sg = new ServiceGroup();
			
			sg.serviceGroupName = rowData.get(0).text();
			
			Element entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusUP").first();
			if(entry != null) sg.hostStatusSummary.hostsUp = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusDOWN").first();
			if(entry != null)sg.hostStatusSummary.hostsDown = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusUNREACHABLE").first();
			if(entry != null)sg.hostStatusSummary.hostsUnreachable = entry.text();
			entry = rowData.get(1).getElementsByAttributeValue("class", "miniStatusPENDING").first();
			if(entry != null)sg.hostStatusSummary.hostsPending = entry.text();
			
			
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusOK").first();
			if(entry != null)sg.serviceStatusSummary.servicesOk = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusWARNING").first();
			if(entry != null)sg.serviceStatusSummary.servicesWarning = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusCRITICAL").first();
			if(entry != null)sg.serviceStatusSummary.servicesCritical = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusUNKNOWN").first();
			if(entry != null)sg.serviceStatusSummary.servicesUnknown = entry.text();
			entry = rowData.get(2).getElementsByAttributeValue("class", "miniStatusPENDING").first();
			if(entry != null)sg.serviceStatusSummary.servicesPending = entry.text();
			
			model.serviceGroups.add(sg);
		}
		
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
		
	}

}
