package at.jku.koppensteiner.androgios.parser;

import java.util.Date;
import java.util.Iterator;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.Host;
import at.jku.koppensteiner.androgios.nagios.model.MonitoringModel;
import at.jku.koppensteiner.androgios.nagios.model.Service;

public class ServiceListParser extends Parser{

	private boolean problemsOnly;
	private boolean filtered;
	
	public ServiceListParser(String html, NagiosInstance instance, boolean problemsOnly ,boolean filtered) {
		super(html, instance);
		this.problemsOnly = problemsOnly;
		this.filtered = filtered;
	}

	@Override
	protected void updateModel(){
		MonitoringModel model = new MonitoringModel();
		
		if(problemsOnly){
			model.lastParsed = MonitoringModel.SERVICEPROBLEMS;
		}else if(filtered){
			model.lastParsed = MonitoringModel.SERVICELISTFILTERED;
		}else{
			model.lastParsed = MonitoringModel.SERVICELIST;
		}
		
		Document doc = Jsoup.parse(html);
		Elements elems = doc.select("TABLE[class=status] > * > tr"); //each table row
		Iterator<Element> it = elems.iterator();
		
		it.next(); //skip headers
		Host host = null;
		Service service = null;
		
		while(it.hasNext()){
			Element row = it.next();
			Elements rowData = row.select(" > td"); // only DIRECT table data descendants of row
			if(rowData.size()==1)continue; // this is a separator
			if(!rowData.get(0).text().equals("")){
				//add new host
				host = new Host();
				host.hostName = rowData.get(0).text();
				model.hosts.add(host);
			}
			// add service
			service = new Service();
			service.serviceName = rowData.get(1).text();
			host.hostServices.add(service);
			
			// set current status
			service.currentStatus = rowData.get(2).text();
			
		}
		
		model.lastUpdate = new Date(System.currentTimeMillis());
		model.updateSuccessful = true;
		instance.model = model;
		
	}

}
