package at.jku.koppensteiner.androgios.parser;


import java.util.Date;


import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.TacticalOverview;

public class TACParser {

	private NagiosInstance instance;
	private String html;
	
	public TACParser(String html, NagiosInstance instance){
		this.instance = instance;
		this.html = html;
	}
	
	public void parse() throws ParserException{
		
		if(html==null)throw new ParserException("html was null");
		
		try{
			updateModel();
		}catch(Exception e){
			throw new ParserException(e.getMessage());
		}
		
		
	}
	
	private void updateModel(){

		TacticalOverview tac = new TacticalOverview();
		
		Document doc = Jsoup.parse(html);
		Elements healthBar = doc.select("[class=healthBar]");
		Elements tables = doc.select("table[class=tac]");
		Element outagesTable = tables.get(0);
		Element hostsTable = tables.get(1);
		Element servicesTable = tables.get(2);
		Element featuresTable = tables.get(3);
		
		
		tac.hostHealth = healthBar.get(0).getElementsByAttribute("alt").attr("alt");
		tac.serviceHealth = healthBar.get(1).getElementsByAttribute("alt").attr("alt");
		
		//Outages
		Elements rows = outagesTable.select("> * > tr");
		tac.outagesSummary.outages = rows.get(1).text();
		
//		for(int i=2;i<rows.size();i++){
//			tac.outagesSummary.outages += " / " + rows.get(i).text();
//		}
		
		Elements importantProblems = outagesTable.select("[class=outageImportantProblem]");
		if(importantProblems.size()!=0) tac.hasImportantOutageProblem = true;
		
		Elements unImportantProblems = outagesTable.select("[class=outageUnimportantProblem]");
		if(unImportantProblems.size()!=0) tac.hasUnimportantOutageProblem = true;
		
		
		//Hosts
		rows = hostsTable.select("> * > tr");
		Elements cols;
		
		cols = rows.get(1).select("> td");
		tac.hostStatusSummary.hostsDown = cols.get(0).text() + ": ";
		tac.hostStatusSummary.hostsUnreachable = cols.get(1).text() + ": ";
		tac.hostStatusSummary.hostsUp = cols.get(2).text() + ": ";
		tac.hostStatusSummary.hostsPending = cols.get(3).text() + ": ";
		
		for(int i=2;i<rows.size();i++){
			cols = rows.get(i).select("> td");
			tac.hostStatusSummary.hostsDown += cols.get(0).text();
			tac.hostStatusSummary.hostsUnreachable += cols.get(1).text();
			tac.hostStatusSummary.hostsUp += cols.get(2).text();
			tac.hostStatusSummary.hostsPending += cols.get(3).text();
		}
		
		
		
		importantProblems = hostsTable.select("[class=hostImportantProblem]");
		if(importantProblems.size()!=0) tac.hasImportantHostProblem = true;
		
		unImportantProblems = hostsTable.select("[class=hostUnimportantProblem]");
		if(unImportantProblems.size()!=0) tac.hasUnimportantHostProblem = true;
		
		//Services
		rows = servicesTable.select("> * > tr");
		cols = rows.get(1).select("> td");
		tac.serviceStatusSummary.servicesCritical = cols.get(0).text() + ": ";
		tac.serviceStatusSummary.servicesWarning = cols.get(1).text() + ": ";
		tac.serviceStatusSummary.servicesUnknown = cols.get(2).text() + ": ";
		tac.serviceStatusSummary.servicesOk = cols.get(3).text() + ": ";
		tac.serviceStatusSummary.servicesPending = cols.get(4).text() + ": ";
		
		for(int i=2;i<rows.size();i++){
			cols = rows.get(i).select("> td");
			tac.serviceStatusSummary.servicesCritical += cols.get(0).text();
			tac.serviceStatusSummary.servicesWarning += cols.get(1).text();
			tac.serviceStatusSummary.servicesUnknown += cols.get(2).text();
			tac.serviceStatusSummary.servicesOk += cols.get(3).text();
			tac.serviceStatusSummary.servicesPending += cols.get(4).text();
		}
		
		importantProblems = servicesTable.select("[class=serviceImportantProblem]");
		if(importantProblems.size()!=0) tac.hasImportantServiceProblem = true;
		
		unImportantProblems = servicesTable.select("[class=serviceUnimportantProblem]");
		if(unImportantProblems.size()!=0) tac.hasUnimportantServiceProblem = true;
		
		
		//Monitoring Features
		rows = featuresTable.select("> * > tr");
		cols = rows.get(2).select("> td");
		
		
		Elements featureEntry = cols.get(0).select("> *  td");
		
		if(featureEntry.size()==3){
			//disabled
			tac.monitoringFeaturesSummary.servicesFlapDetection = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.servicesFlapping = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsFlapDetection = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsFlapping = featureEntry.get(2).text();
		}else if(featureEntry.size()==7){
			//enabled
			tac.monitoringFeaturesSummary.servicesFlapDetection = featureEntry.get(3).text();
			tac.monitoringFeaturesSummary.servicesFlapping = featureEntry.get(4).text();
			tac.monitoringFeaturesSummary.hostsFlapDetection = featureEntry.get(5).text();
			tac.monitoringFeaturesSummary.hostsFlapping = featureEntry.get(6).text();
		}
		
		featureEntry = cols.get(1).select("> *  td");
		
		if(featureEntry.size()==3){
			//disabled
			tac.monitoringFeaturesSummary.servicesNotifications = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsNotifications = featureEntry.get(2).text();
		}else if(featureEntry.size()==5){
			//enabled
			tac.monitoringFeaturesSummary.servicesNotifications = featureEntry.get(3).text();
			tac.monitoringFeaturesSummary.hostsNotifications = featureEntry.get(4).text();
		}
		
		featureEntry = cols.get(2).select("> *  td");
		
		if(featureEntry.size()==3){
			tac.monitoringFeaturesSummary.servicesEventHandlers = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsEventHandlers = featureEntry.get(2).text();
		}else if(featureEntry.size()==5){
			tac.monitoringFeaturesSummary.servicesEventHandlers = featureEntry.get(3).text();
			tac.monitoringFeaturesSummary.hostsEventHandlers = featureEntry.get(4).text();
		}
		
		featureEntry = cols.get(3).select("> *  td");
		
		if(featureEntry.size()==3){
			tac.monitoringFeaturesSummary.servicesActiveChecks = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsActiveChecks = featureEntry.get(2).text();
		}else if(featureEntry.size()==5){
			tac.monitoringFeaturesSummary.servicesActiveChecks = featureEntry.get(3).text();
			tac.monitoringFeaturesSummary.hostsActiveChecks = featureEntry.get(4).text();
		}
		
		featureEntry = cols.get(4).select("> *  td");
		
		if(featureEntry.size()==3){
			tac.monitoringFeaturesSummary.servicesPassiveChecks = featureEntry.get(2).text();
			tac.monitoringFeaturesSummary.hostsPassiveChecks = featureEntry.get(2).text();
		}else if(featureEntry.size()==5){
			tac.monitoringFeaturesSummary.servicesPassiveChecks = featureEntry.get(3).text();
			tac.monitoringFeaturesSummary.hostsPassiveChecks = featureEntry.get(4).text();
		}
		
		
		tac.lastUpdate = new Date(System.currentTimeMillis());
		tac.updateSuccessful = true;
		instance.tacticalOverview = tac;
	}
	
}
