package at.jku.koppensteiner.androgios.service;


import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

import android.app.AlarmManager;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.media.Ringtone;
import android.media.RingtoneManager;
import android.net.Uri;
import android.os.IBinder;
import android.os.SystemClock;
import android.os.Vibrator;
import at.jku.koppensteiner.androgios.AndrogiosActivity;
import at.jku.koppensteiner.androgios.R;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.TacticalOverview;

public class PollingService extends Service{

	private class updateReceiver extends BroadcastReceiver{

		@Override
		public void onReceive(Context context, Intent intent) {
			
			TacticalOverview tac = MasterController.getInstance().getActiveNagiosInstance().tacticalOverview;
			
			if(!tac.updateSuccessful && MasterController.getInstance().alarmOnUpdateFailed){
				doAlarm();
			}
				
			if(tac.updateSuccessful && tac.hasImportantProblem()){
				doAlarm();
			}
			
			if(tac.updateSuccessful && !tac.hasImportantProblem()){
				((NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE)).cancel(NOTIFY_ID);
			}
			
		}
		
	}
	
	
	public static boolean running;
	public static final int NOTIFY_ID = 87766776;
	
	private updateReceiver updateReceiver = new updateReceiver();
	private AlarmManager am = null;
	
	PollingThread pt;
	
	public PollingService() {
		super();
		running = false;
		
	}
	
	
	
	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}
	
	
	@Override
	public void onStart(Intent intent, int startId) {
		
		
		NagiosInstance nagiosInstance = MasterController.getInstance().getActiveNagiosInstance();
		if(!running){
			am = (AlarmManager)getSystemService(ALARM_SERVICE);
			running = true;
			
			am.cancel(getOperation());
			am.set(AlarmManager.ELAPSED_REALTIME_WAKEUP, SystemClock.elapsedRealtime()+nagiosInstance.pollIntervall * 1000, getOperation());
			
		}else{
			pt = new PollingThread(nagiosInstance);
			pt.start();
		}
		
		
		
	}
	
	@Override
	public void onDestroy(){
		am.cancel(getOperation());
		try{
			registerReceiver(false);
		}catch (Exception e){
			
		}
		
		running = false;
	}
	
	
	
	private PendingIntent getOperation(){
		
		Intent intent = new Intent(".service.PollingService");
		PendingIntent op = PendingIntent.getService(getApplicationContext(), 0, intent, 0);
		
		return op;
		
	}
	
	
	

	private class PollingThread extends Thread{
		
		private final NagiosInstance nagiosInstance;
		
		public PollingThread(NagiosInstance nagInst){
			this.nagiosInstance = nagInst;
		}
		
		@Override
		public void run(){

			Calendar now = GregorianCalendar.getInstance();
			now.setTime(new Date(System.currentTimeMillis()));
			
			if(MasterController.getInstance().withinPollFreeInterval(now)){
				
				Calendar end = MasterController.getInstance().getPollFreeIntervallEnd();
				
				
				long millis = 0;
				
				if(end.get(Calendar.HOUR_OF_DAY)==now.get(Calendar.HOUR_OF_DAY)){
					millis = (end.get(Calendar.MINUTE) - now.get(Calendar.MINUTE))*60*1000;
				}else{
					millis = 60 - now.get(Calendar.MINUTE);
					millis += (end.get(Calendar.HOUR_OF_DAY) - (now.get(Calendar.HOUR_OF_DAY)+1))*60;
					millis += end.get(Calendar.MINUTE);
					millis *= 60*1000;
				}
				
				
				am.set(AlarmManager.ELAPSED_REALTIME_WAKEUP, SystemClock.elapsedRealtime()+millis, getOperation());
			}else{
				
				nagiosInstance.pollTacticalOverview();
				if(!MasterController.getInstance().withinAlarmFreeInterval(now)){
					registerReceiver(true);
				}
				
				am.set(AlarmManager.ELAPSED_REALTIME_WAKEUP, SystemClock.elapsedRealtime()+nagiosInstance.pollIntervall * 1000, getOperation());
			}
			
		}
		
		

		
	}
	
	private void doAlarm(){
		
		TacticalOverview tac = MasterController.getInstance().getActiveNagiosInstance().tacticalOverview;

		
		String notificationMessage;
		if(tac.hasImportantProblem()){
			notificationMessage = getApplicationContext().getString(R.string.problemOccured);
		}else{
			notificationMessage = getApplicationContext().getString(R.string.updatefailed);
		}
			
		//notification icon
		
		final Context ctx = getApplicationContext();
		final NotificationManager nm = (NotificationManager)getSystemService(Context.NOTIFICATION_SERVICE);
		final Notification n = new Notification(R.drawable.icon_red, notificationMessage, System.currentTimeMillis());
		
		final Intent i = new Intent(ctx, AndrogiosActivity.class);
		i.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
		
		final PendingIntent pi = PendingIntent.getActivity(ctx, 0, i, 0);
		
		n.setLatestEventInfo(ctx, ctx.getString(R.string.app_name), notificationMessage, pi);
		
		nm.notify(NOTIFY_ID, n);
		
		
		//vibration
		if(MasterController.getInstance().vibrateOnAlarm){
			Vibrator v = (Vibrator) getSystemService(Context.VIBRATOR_SERVICE);
	    	v.vibrate(2000);
		}
		
		//alarmtone
		if(MasterController.getInstance().soundOnAlarm){
			Uri uri = Uri.parse("android.resource://at.jku.koppensteiner.androgios/raw/msg");
			Ringtone r = RingtoneManager.getRingtone(ctx, uri);
			r.play();
			while(r.isPlaying()){
				//wait for tone completion
			}
		}
		
		registerReceiver(false);
		
		
	}
	

	
	private void registerReceiver(boolean b){
		if(b){
			getApplicationContext().registerReceiver(updateReceiver, 
					new IntentFilter(AndrogiosActivity.ACTION_TAC_UPDATE));
		}else{
			getApplicationContext().unregisterReceiver(updateReceiver);
		}
	}

}
