package at.jku.koppensteiner.androgios.util;

import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.app.DatePickerDialog.OnDateSetListener;
import android.app.TimePickerDialog.OnTimeSetListener;
import android.content.Context;
import android.view.View;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.LinearLayout;
import android.widget.TimePicker;

public class DateTimePicker extends LinearLayout {

	private Button date ;
	private Button time ;
	
	private DatePickerDialog datePickerdlg;
	private TimePickerDialog timePickerdlg;
	
	private Calendar cal;
	
	
	public DateTimePicker(Context context) {
		super(context);
		
		this.setOrientation(HORIZONTAL);
		date = new Button(context);
		time = new Button(context);
		
		
		cal = GregorianCalendar.getInstance();
		cal.setTime(new Date(System.currentTimeMillis()));
		
		datePickerdlg = new DatePickerDialog(context,getOnDateSetListener(),cal.get(Calendar.YEAR),cal.get(Calendar.MONTH),cal.get(Calendar.DATE));
		timePickerdlg = new TimePickerDialog(context, getOnTimeSetListener(), cal.get(Calendar.HOUR_OF_DAY), cal.get(Calendar.MINUTE), true);
		
		date.setOnClickListener(getDateOnClickListener());
		time.setOnClickListener(getTimeOnClickListener());
		
		StringBuilder sb = new StringBuilder();
		sb.append(cal.get(Calendar.YEAR));
		sb.append("-");
		sb.append(pad(cal.get(Calendar.MONTH)+1));
		sb.append("-");
		sb.append(pad(cal.get(Calendar.DATE)));
		
		date.setText(sb.toString());
		
		sb = new StringBuilder();
		sb.append(pad(cal.get(Calendar.HOUR_OF_DAY)));
		sb.append(":");
		sb.append(pad(cal.get(Calendar.MINUTE)));
		
		time.setText(sb.toString());
		
		
		addView(date);
		addView(time);
		
		
	}
	
	public Calendar getValue(){
		return cal;
	}
	
	public String getDateString(String format){
		

		
		if(format.equals("us")){
			return DateHelper.us(cal.getTime());
		}else if(format.equals("euro")){
			return DateHelper.euro(cal.getTime());
		}else if(format.equals("iso8601")){
			return DateHelper.iso8601(cal.getTime());
		}else if(format.equals("strict-iso8601")){
			return DateHelper.strictIso8601(cal.getTime());
		}
		
		throw new IllegalArgumentException("Unsupported Date Format");
		
	}
	
	
	private OnClickListener getDateOnClickListener(){
		return new OnClickListener(){

			@Override
			public void onClick(View v) {
				datePickerdlg.show();
			}
			
		};
		
	}
	
	private OnClickListener getTimeOnClickListener(){
		return new OnClickListener(){

			@Override
			public void onClick(View v) {
				timePickerdlg.show();
			}
			
		};
		
	}
	
	
	private OnDateSetListener getOnDateSetListener(){
		return new OnDateSetListener(){

			@Override
			public void onDateSet(DatePicker view, int year, int monthOfYear,
					int dayOfMonth) {
				
				cal.set(Calendar.YEAR, year);
				cal.set(Calendar.MONTH, monthOfYear);
				cal.set(Calendar.DAY_OF_MONTH, dayOfMonth);
				
				StringBuilder sb = new StringBuilder();
				sb.append(cal.get(Calendar.YEAR));
				sb.append("-");
				sb.append(pad(cal.get(Calendar.MONTH)+1));
				sb.append("-");
				sb.append(pad(cal.get(Calendar.DAY_OF_MONTH)));
				
				date.setText(sb.toString());
				
			}
		};
		
	}
	
	private OnTimeSetListener getOnTimeSetListener(){
		return new OnTimeSetListener(){

				@Override
				public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
					cal.set(Calendar.HOUR_OF_DAY, hourOfDay);
					cal.set(Calendar.MINUTE, minute);
					
					StringBuilder sb = new StringBuilder();
					sb.append(pad(cal.get(Calendar.HOUR_OF_DAY)));
					sb.append(":");
					sb.append(pad(cal.get(Calendar.MINUTE)));
					
					time.setText(sb.toString());
					
				}

			};
		
	}
	
	
	private String pad(int c) {
	    if (c >= 10)
	        return String.valueOf(c);
	    else
	        return "0" + String.valueOf(c);
	}
	
}
