package at.jku.koppensteiner.androgios.util;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;

public class PostDataBuilder {

	public static final int DOWNTIMETYPE_FIXED = 1;
	public static final int DOWNTIMETYPE_FLEXIBLE = 0;
	
	public static final int DO_NOTHING_WITH_CHILD_HOSTS = 0;
	public static final int SCHEDULE_TRIGGERED_DOWNTIME_FORALL_CHILD_HOSTS = 1;
	public static final int SCHEDULE_NONTRIGGERED_DOWNTIME_FORALL_CHILD_HOSTS = 2;
	
	
	//@Hosts
	
	public static String enableHostCheck(String hostName){
		return hostCmd("47", hostName);
	}
	
	public static String disableHostCheck(String hostName){
		return hostCmd("48", hostName);
	}
	
	public static String scheduleHostCheck(String hostName, String checkTime, boolean force){
		StringBuilder sb = new StringBuilder(hostCmd("96", hostName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("start_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(checkTime, "UTF-8"));
			if(force){
				sb.append("&");
				sb.append(URLEncoder.encode("force_check", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String enablePassiveHostChecks(String hostName){
		return hostCmd("92", hostName);
	}
	
	public static String disablePassiveHostChecks(String hostName){
		return hostCmd("93", hostName);
	}
	
	public static String acknowledgeHostProblem(String hostName, String author, String comment, 
			boolean sticky, boolean sendNotification, boolean persistentComment){
		StringBuilder sb = new StringBuilder(hostCmd("33", hostName));
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			if(sticky){
				sb.append("&");
				sb.append(URLEncoder.encode("sticky_ack", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
			if(sendNotification){
				sb.append("&");
				sb.append(URLEncoder.encode("send_notification", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
			if(persistentComment){
				sb.append("&");
				sb.append(URLEncoder.encode("persistent", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		return sb.toString();
	}
	
	public static String removeHostAcknoledgement(String hostName){
		return hostCmd("51", hostName);
	}
	
	public static String enableHostNotifications(String hostName, boolean alsoChildHosts){
		StringBuilder sb = new StringBuilder(hostCmd("24", hostName));
		if(alsoChildHosts){
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ptc", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}catch(UnsupportedEncodingException e){}
			
		}
		return sb.toString();
	}
	
	public static String disableHostNotifications(String hostName, boolean alsoChildHosts){
		StringBuilder sb = new StringBuilder(hostCmd("25", hostName));
		if(alsoChildHosts){
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ptc", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}catch(UnsupportedEncodingException e){}
			
		}
		return sb.toString();
	}
	
	public static String scheduleHostDowntime(String hostName, String author, String comment, 
			String startTime, String endTime,
			int childOptions, int type, String hours, String minutes){
		
		StringBuilder sb = new StringBuilder(hostCmd("55", hostName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("start_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(startTime, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("end_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(endTime, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("fixed", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(String.valueOf(type), "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("childoptions", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(String.valueOf(childOptions), "UTF-8"));
			
			if(type == DOWNTIMETYPE_FLEXIBLE){
				sb.append("&");
				sb.append(URLEncoder.encode("hours", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode(hours, "UTF-8"));
				
				sb.append("&");
				sb.append(URLEncoder.encode("minutes", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode(minutes, "UTF-8"));
			}
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	
	
	public static String enableHostSvcNotifications(String hostName, boolean alsoHost){
		StringBuilder sb = new StringBuilder(hostCmd("28", hostName));
		if(alsoHost){
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ahas", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}catch(UnsupportedEncodingException e){}
			
		}
		return sb.toString();
	}
	
	public static String disableHostSvcNotifications(String hostName, boolean alsoHost){
		StringBuilder sb = new StringBuilder(hostCmd("29", hostName));
		if(alsoHost){
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ahas", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}catch(UnsupportedEncodingException e){}
			
		}
		return sb.toString();
	}
	
	public static String startObsessingOverHost(String hostName){
		return hostCmd("101", hostName);
	}
	
	public static String stopObsessingOverHost(String hostName){
		return hostCmd("102", hostName);
	}
	
	public static String enableHostFlapDetection(String hostName){
		return hostCmd("57", hostName);
	}
	
	public static String disableHostFlapDetection(String hostName){
		return hostCmd("58", hostName);
	}

	public static String enableHostEventHandler(String hostName){
		return hostCmd("43", hostName);
	}
	
	public static String disableHostEventHandler(String hostName){
		return hostCmd("44", hostName);
	}
	
	public static String enableHostSvcChecks(String hostName, boolean alsoHost){
		StringBuffer sb = new StringBuffer(hostCmd("15", hostName));
		
		if(alsoHost){
			
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ahas", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
				
			}catch(UnsupportedEncodingException e){
				return "";
			}
		}
		return sb.toString();
	}
	
	public static String disableHostSvcChecks(String hostName, boolean alsoHost){
		StringBuffer sb = new StringBuffer(hostCmd("16", hostName));
		
		if(alsoHost){
			
			try{
				sb.append("&");
				sb.append(URLEncoder.encode("ahas", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
				
			}catch(UnsupportedEncodingException e){
				return "";
			}
		}
		return sb.toString();
	}
	
	public static String scheduleHostSvcChecks(String hostName, String time, boolean force){
		
		StringBuffer sb = new StringBuffer(hostCmd("17", hostName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("start_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(time, "UTF-8"));
			if(force){
				sb.append("&");
				sb.append(URLEncoder.encode("force_check", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		
		return sb.toString();
	}
	
	
	private static String hostCmd(String cmdTyp, String hostName){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(cmdTyp, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("host", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(hostName, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	
	private static String svcCmd(String cmdTyp, String hostName, String serviceName){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(cmdTyp, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("host", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(hostName, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("service", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(serviceName, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	//@Services
	public static String enableSvcCheck(String hostName, String serviceName){
		return svcCmd("5", hostName, serviceName);
	}
	
	public static String disableSvcCheck(String hostName, String serviceName){
		return svcCmd("6", hostName, serviceName);
	}
	
	public static String scheduleSvcCheck(String hostName, String serviceName, String checkTime, boolean force){
		StringBuilder sb = new StringBuilder(svcCmd("7", hostName, serviceName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("start_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(checkTime, "UTF-8"));
			if(force){
				sb.append("&");
				sb.append(URLEncoder.encode("force_check", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String enablePassiveSvcChecks(String hostName, String serviceName){
		return svcCmd("39", hostName, serviceName);
	}
	
	public static String disablePassiveSvcChecks(String hostName, String serviceName){
		return svcCmd("40", hostName, serviceName);
	}
	
	public static String acknowledgeSvcProblem(String hostName, String serviceName, 
			String author, String comment, 
			boolean sticky, boolean sendNotification, boolean persistentComment){
		
		StringBuilder sb = new StringBuilder(svcCmd("34", hostName, serviceName));
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			if(sticky){
				sb.append("&");
				sb.append(URLEncoder.encode("sticky_ack", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
			if(sendNotification){
				sb.append("&");
				sb.append(URLEncoder.encode("send_notification", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
			if(persistentComment){
				sb.append("&");
				sb.append(URLEncoder.encode("persistent", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		return sb.toString();
	}
	
	public static String removeSvcAcknowledgement(String hostName, String serviceName){
		return svcCmd("52", hostName, serviceName);
	}
	
	public static String enableSvcNotifications(String hostName, String serviceName){
		return svcCmd("22", hostName, serviceName);
	}
	
	public static String disableSvcNotifications(String hostName, String serviceName){
		return svcCmd("23", hostName, serviceName);
	}
	
	public static String scheduleSvcDowntime(String hostName, String serviceName, 
			String author, String comment, 
			String startTime, String endTime,
			int type, String hours, String minutes){
		
		StringBuilder sb = new StringBuilder(svcCmd("56", hostName, serviceName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("start_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(startTime, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("end_time", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(endTime, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("fixed", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(String.valueOf(type), "UTF-8"));
			
			
			if(type == DOWNTIMETYPE_FLEXIBLE){
				sb.append("&");
				sb.append(URLEncoder.encode("hours", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode(hours, "UTF-8"));
				
				sb.append("&");
				sb.append(URLEncoder.encode("minutes", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode(minutes, "UTF-8"));
			}
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String enableSvcEventHandler(String hostName, String serviceName){
		return svcCmd("45", hostName, serviceName);
	}
	
	public static String disableSvcEventHandler(String hostName, String serviceName){
		return svcCmd("46", hostName, serviceName);
	}
	
	public static String enableSvcFlapDetection(String hostName, String serviceName){
		return svcCmd("59", hostName, serviceName);
	}
	
	public static String disableSvcFlapDetection(String hostName, String serviceName){
		return svcCmd("60", hostName, serviceName);
	}
	
	public static String startObsessingOverService(String hostName, String serviceName){
		return svcCmd("99", hostName, serviceName);
	}
	
	public static String stopObsessingOverService(String hostName, String serviceName){
		return svcCmd("100", hostName, serviceName);
	}
	
	
	//@Comments
	
	public static String addHostComment(String hostName, String author, String comment, boolean persistent){
		
		StringBuilder sb = new StringBuilder(hostCmd("1", hostName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			
			
			if(persistent){
				sb.append("&");
				sb.append(URLEncoder.encode("persistent", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String addSvcComment(String hostName, String serviceName, String author, String comment, boolean persistent){
		StringBuilder sb = new StringBuilder(svcCmd("3", hostName, serviceName));
		
		try{
			sb.append("&");
			sb.append(URLEncoder.encode("com_author", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(author, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_data", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(comment, "UTF-8"));
			
			
			if(persistent){
				sb.append("&");
				sb.append(URLEncoder.encode("persistent", "UTF-8"));
				sb.append("=");
				sb.append(URLEncoder.encode("on", "UTF-8"));
			}
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String delHostComment(String commentId){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_id", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(commentId, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String delSvcComment(String commentId){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("4", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("com_id", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(commentId, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String delAllHostComments(String hostName){
		return hostCmd("20", hostName);
	}
	
	public static String delAllSvcComments(String hostName, String serviceName){
		return svcCmd("21", hostName, serviceName);
	}
	
	//@Downtimes
	public static String delHostDowntime(String downtimeId){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("78", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("down_id", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(downtimeId, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	public static String delSvcDowntime(String downtimeId){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("79", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("down_id", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(downtimeId, "UTF-8"));
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
	//@Process
	public static String shutdownProgram(){
		return processCmd("14");
	}
	
	public static String restartProgram(){
		return processCmd("13");
	}
	
	public static String enableNotifications(){
		return processCmd("12");
	}
	
	public static String disableNotifications(){
		return processCmd("11");
	}
	
	public static String startExecutingSvcChecks(){
		return processCmd("35");
	}
	
	public static String stopExecutingSvcChecks(){
		return processCmd("36");
	}
	
	public static String startAcceptingPassiveSvcChecks(){
		return processCmd("37");
	}
	
	public static String stopAcceptingPassiveSvcChecks(){
		return processCmd("38");
	}
	
	public static String startExecutingHostChecks(){
		return processCmd("88");
	}
	
	public static String stopExecutingHostChecks(){
		return processCmd("89");
	}
	
	public static String startAcceptingPassiveHostChecks(){
		return processCmd("90");
	}
	
	public static String stopAcceptingPassiveHostChecks(){
		return processCmd("91");
	}
	
	public static String enableEventHandlers(){
		return processCmd("41");
	}
	
	public static String disableEventHandlers(){
		return processCmd("42");
	}
	
	public static String startObsessingOverSvc(){
		return processCmd("49");
	}
	
	public static String stopObsessingOverSvc(){
		return processCmd("50");
	}
	
	public static String startObsessingOverHost(){
		return processCmd("94");
	}
	
	public static String stopObsessingOverHost(){
		return processCmd("95");
	}
	
	public static String enableFlapDetection(){
		return processCmd("61");
	}
	
	public static String disableFlapDetection(){
		return processCmd("62");
	}
	
	public static String enablePerformanceData(){
		return processCmd("82");
	}
	
	public static String disablePerformanceData(){
		return processCmd("83");
	}
	
	private static String processCmd(String cmdTyp){
		StringBuilder sb = new StringBuilder();
		try {
			
			sb.append(URLEncoder.encode("cmd_typ", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode(cmdTyp, "UTF-8"));
			
			sb.append("&");
			sb.append(URLEncoder.encode("cmd_mod", "UTF-8"));
			sb.append("=");
			sb.append(URLEncoder.encode("2", "UTF-8"));
			
			
			
		}catch(UnsupportedEncodingException e){
			return "";
		}
		
		return sb.toString();
	}
	
}
