package at.jku.koppensteiner.androgios.widget;

import java.text.DateFormat;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.widget.RemoteViews;

import at.jku.koppensteiner.androgios.AndrogiosActivity;
import at.jku.koppensteiner.androgios.R;
import at.jku.koppensteiner.androgios.nagios.MasterController;
import at.jku.koppensteiner.androgios.nagios.NagiosInstance;
import at.jku.koppensteiner.androgios.nagios.model.TacticalOverview;

public class AndrogiosWidget extends AppWidgetProvider{
	
	
	@Override
	public void onReceive(Context context, Intent intent) {
		
		
		AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
	    ComponentName thisAppWidget = new ComponentName(context.getPackageName(), AndrogiosWidget.class.getName());
	    int[] appWidgetIds = appWidgetManager.getAppWidgetIds(thisAppWidget);

	    updateWidgets(context, appWidgetManager, appWidgetIds);
	}
	
	private void updateWidgets(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) {
		
		NagiosInstance n = MasterController.getInstance().getActiveNagiosInstance();
		if(n==null)return;
		TacticalOverview tac = n.tacticalOverview;
		String lastPoll, hostHealth, serviceHealth, outages;
		if(tac==null||!tac.updateSuccessful){
			
			lastPoll = context.getString(R.string.updatefailed);
			hostHealth = "";
			serviceHealth = "";
			outages = "";
			
		}else{
			lastPoll = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT).format(tac.lastUpdate);
			hostHealth = context.getString(R.string.hostsHeader) + tac.hostHealth;
			serviceHealth = context.getString(R.string.servicesHeader) + tac.serviceHealth;
			outages = context.getString(R.string.outagesHeader) + tac.outagesSummary.outages;
		}
		
		
		for (int i=0; i<appWidgetIds.length; i++) {
			RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.androgios_widget_layout);
			

			views.setTextViewText(R.id.textViewLastPoll, lastPoll);
			views.setTextViewText(R.id.textViewHostHealth, hostHealth);
			views.setTextViewText(R.id.textViewServiceHealth, serviceHealth);
			views.setTextViewText(R.id.textViewOutages, outages);
			
			
			appWidgetManager.updateAppWidget(appWidgetIds[i], views);
		}
		
		
		setClickListeners(context);
	
	}
	
	@Override
	public void onEnabled(Context context){
		super.onEnabled(context);
		setClickListeners(context);
	}
	
		
	
	private void setClickListeners(Context context) {
		
		Intent intent = new Intent(); 
		intent.putExtra("POLLED", true);
	    intent.setClass(context, AndrogiosActivity.class); 
	    PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, intent, 0);

	    RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.androgios_widget_layout); 

	    //attach the click listeners
	    views.setOnClickPendingIntent(R.id.llWidget, pendingIntent); 
	    views.setOnClickPendingIntent(R.id.textViewAppName, pendingIntent); 
	    views.setOnClickPendingIntent(R.id.textViewLastPoll, pendingIntent); 
	    views.setOnClickPendingIntent(R.id.textViewHostHealth, pendingIntent); 
	    views.setOnClickPendingIntent(R.id.textViewServiceHealth, pendingIntent); 
	    views.setOnClickPendingIntent(R.id.textViewOutages, pendingIntent); 
	      
	      
	    ComponentName comp = new ComponentName(context.getPackageName(), AndrogiosWidget.class.getName()); 
	    AppWidgetManager.getInstance(context).updateAppWidget(comp, views); 
		
	}

	

	
	
	
}
